# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
TPrsStd module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_tprsstd.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _TPrsStd
else:
    import _TPrsStd

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _TPrsStd.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _TPrsStd.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _TPrsStd.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _TPrsStd.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _TPrsStd.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _TPrsStd.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _TPrsStd.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _TPrsStd.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _TPrsStd.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _TPrsStd.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _TPrsStd.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _TPrsStd.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _TPrsStd.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _TPrsStd.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _TPrsStd.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _TPrsStd.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _TPrsStd.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _TPrsStd:
_TPrsStd.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _TPrsStd.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TDF
import OCC.Core.TCollection
import OCC.Core.TColStd
import OCC.Core.Quantity
import OCC.Core.AIS
import OCC.Core.SelectMgr
import OCC.Core.Graphic3d
import OCC.Core.BVH
import OCC.Core.gp
import OCC.Core.Aspect
import OCC.Core.Image
import OCC.Core.TopLoc
import OCC.Core.Bnd
import OCC.Core.TColgp
import OCC.Core.OSD
import OCC.Core.Media
import OCC.Core.Select3D
import OCC.Core.SelectBasics
import OCC.Core.Geom
import OCC.Core.GeomAbs
import OCC.Core.PrsMgr
import OCC.Core.Prs3d
import OCC.Core.Poly
import OCC.Core.TShort
import OCC.Core.V3d
import OCC.Core.TopAbs
import OCC.Core.TopoDS
import OCC.Core.Message
import OCC.Core.StdSelect
import OCC.Core.TDataXtd
import OCC.Core.TDataStd
import OCC.Core.TNaming
import OCC.Core.TopTools

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_TPrsStd_AISPresentation_Create() -> "opencascade::handle< TPrsStd_AISPresentation >":
    return _TPrsStd.Handle_TPrsStd_AISPresentation_Create()

def Handle_TPrsStd_AISPresentation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TPrsStd_AISPresentation >":
    return _TPrsStd.Handle_TPrsStd_AISPresentation_DownCast(t)

def Handle_TPrsStd_AISPresentation_IsNull(t: "opencascade::handle< TPrsStd_AISPresentation > const &") -> "bool":
    return _TPrsStd.Handle_TPrsStd_AISPresentation_IsNull(t)

def Handle_TPrsStd_AISViewer_Create() -> "opencascade::handle< TPrsStd_AISViewer >":
    return _TPrsStd.Handle_TPrsStd_AISViewer_Create()

def Handle_TPrsStd_AISViewer_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TPrsStd_AISViewer >":
    return _TPrsStd.Handle_TPrsStd_AISViewer_DownCast(t)

def Handle_TPrsStd_AISViewer_IsNull(t: "opencascade::handle< TPrsStd_AISViewer > const &") -> "bool":
    return _TPrsStd.Handle_TPrsStd_AISViewer_IsNull(t)

def Handle_TPrsStd_Driver_Create() -> "opencascade::handle< TPrsStd_Driver >":
    return _TPrsStd.Handle_TPrsStd_Driver_Create()

def Handle_TPrsStd_Driver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TPrsStd_Driver >":
    return _TPrsStd.Handle_TPrsStd_Driver_DownCast(t)

def Handle_TPrsStd_Driver_IsNull(t: "opencascade::handle< TPrsStd_Driver > const &") -> "bool":
    return _TPrsStd.Handle_TPrsStd_Driver_IsNull(t)

def Handle_TPrsStd_DriverTable_Create() -> "opencascade::handle< TPrsStd_DriverTable >":
    return _TPrsStd.Handle_TPrsStd_DriverTable_Create()

def Handle_TPrsStd_DriverTable_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TPrsStd_DriverTable >":
    return _TPrsStd.Handle_TPrsStd_DriverTable_DownCast(t)

def Handle_TPrsStd_DriverTable_IsNull(t: "opencascade::handle< TPrsStd_DriverTable > const &") -> "bool":
    return _TPrsStd.Handle_TPrsStd_DriverTable_IsNull(t)

def Handle_TPrsStd_AxisDriver_Create() -> "opencascade::handle< TPrsStd_AxisDriver >":
    return _TPrsStd.Handle_TPrsStd_AxisDriver_Create()

def Handle_TPrsStd_AxisDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TPrsStd_AxisDriver >":
    return _TPrsStd.Handle_TPrsStd_AxisDriver_DownCast(t)

def Handle_TPrsStd_AxisDriver_IsNull(t: "opencascade::handle< TPrsStd_AxisDriver > const &") -> "bool":
    return _TPrsStd.Handle_TPrsStd_AxisDriver_IsNull(t)

def Handle_TPrsStd_ConstraintDriver_Create() -> "opencascade::handle< TPrsStd_ConstraintDriver >":
    return _TPrsStd.Handle_TPrsStd_ConstraintDriver_Create()

def Handle_TPrsStd_ConstraintDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TPrsStd_ConstraintDriver >":
    return _TPrsStd.Handle_TPrsStd_ConstraintDriver_DownCast(t)

def Handle_TPrsStd_ConstraintDriver_IsNull(t: "opencascade::handle< TPrsStd_ConstraintDriver > const &") -> "bool":
    return _TPrsStd.Handle_TPrsStd_ConstraintDriver_IsNull(t)

def Handle_TPrsStd_GeometryDriver_Create() -> "opencascade::handle< TPrsStd_GeometryDriver >":
    return _TPrsStd.Handle_TPrsStd_GeometryDriver_Create()

def Handle_TPrsStd_GeometryDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TPrsStd_GeometryDriver >":
    return _TPrsStd.Handle_TPrsStd_GeometryDriver_DownCast(t)

def Handle_TPrsStd_GeometryDriver_IsNull(t: "opencascade::handle< TPrsStd_GeometryDriver > const &") -> "bool":
    return _TPrsStd.Handle_TPrsStd_GeometryDriver_IsNull(t)

def Handle_TPrsStd_NamedShapeDriver_Create() -> "opencascade::handle< TPrsStd_NamedShapeDriver >":
    return _TPrsStd.Handle_TPrsStd_NamedShapeDriver_Create()

def Handle_TPrsStd_NamedShapeDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TPrsStd_NamedShapeDriver >":
    return _TPrsStd.Handle_TPrsStd_NamedShapeDriver_DownCast(t)

def Handle_TPrsStd_NamedShapeDriver_IsNull(t: "opencascade::handle< TPrsStd_NamedShapeDriver > const &") -> "bool":
    return _TPrsStd.Handle_TPrsStd_NamedShapeDriver_IsNull(t)

def Handle_TPrsStd_PlaneDriver_Create() -> "opencascade::handle< TPrsStd_PlaneDriver >":
    return _TPrsStd.Handle_TPrsStd_PlaneDriver_Create()

def Handle_TPrsStd_PlaneDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TPrsStd_PlaneDriver >":
    return _TPrsStd.Handle_TPrsStd_PlaneDriver_DownCast(t)

def Handle_TPrsStd_PlaneDriver_IsNull(t: "opencascade::handle< TPrsStd_PlaneDriver > const &") -> "bool":
    return _TPrsStd.Handle_TPrsStd_PlaneDriver_IsNull(t)

def Handle_TPrsStd_PointDriver_Create() -> "opencascade::handle< TPrsStd_PointDriver >":
    return _TPrsStd.Handle_TPrsStd_PointDriver_Create()

def Handle_TPrsStd_PointDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TPrsStd_PointDriver >":
    return _TPrsStd.Handle_TPrsStd_PointDriver_DownCast(t)

def Handle_TPrsStd_PointDriver_IsNull(t: "opencascade::handle< TPrsStd_PointDriver > const &") -> "bool":
    return _TPrsStd.Handle_TPrsStd_PointDriver_IsNull(t)
class TPrsStd_DataMapOfGUIDDriver(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_DataMap< Standard_GUID,opencascade::handle< TPrsStd_Driver >,Standard_GUID >::iterator":
        return _TPrsStd.TPrsStd_DataMapOfGUIDDriver_begin(self)

    def end(self) -> "NCollection_DataMap< Standard_GUID,opencascade::handle< TPrsStd_Driver >,Standard_GUID >::iterator":
        return _TPrsStd.TPrsStd_DataMapOfGUIDDriver_end(self)

    def cbegin(self) -> "NCollection_DataMap< Standard_GUID,opencascade::handle< TPrsStd_Driver >,Standard_GUID >::const_iterator":
        return _TPrsStd.TPrsStd_DataMapOfGUIDDriver_cbegin(self)

    def cend(self) -> "NCollection_DataMap< Standard_GUID,opencascade::handle< TPrsStd_Driver >,Standard_GUID >::const_iterator":
        return _TPrsStd.TPrsStd_DataMapOfGUIDDriver_cend(self)

    def __init__(self, *args):
        _TPrsStd.TPrsStd_DataMapOfGUIDDriver_swiginit(self, _TPrsStd.new_TPrsStd_DataMapOfGUIDDriver(*args))

    def Exchange(self, theOther: "TPrsStd_DataMapOfGUIDDriver") -> "void":
        return _TPrsStd.TPrsStd_DataMapOfGUIDDriver_Exchange(self, theOther)

    def Assign(self, theOther: "TPrsStd_DataMapOfGUIDDriver") -> "NCollection_DataMap< Standard_GUID,opencascade::handle< TPrsStd_Driver >,Standard_GUID > &":
        return _TPrsStd.TPrsStd_DataMapOfGUIDDriver_Assign(self, theOther)

    def Set(self, theOther: "TPrsStd_DataMapOfGUIDDriver") -> "NCollection_DataMap< Standard_GUID,opencascade::handle< TPrsStd_Driver >,Standard_GUID > &":
        return _TPrsStd.TPrsStd_DataMapOfGUIDDriver_Set(self, theOther)

    def ReSize(self, N: "Standard_Integer const") -> "void":
        return _TPrsStd.TPrsStd_DataMapOfGUIDDriver_ReSize(self, N)

    def Bind(self, theKey: "Standard_GUID", theItem: "opencascade::handle< TPrsStd_Driver > const &") -> "Standard_Boolean":
        return _TPrsStd.TPrsStd_DataMapOfGUIDDriver_Bind(self, theKey, theItem)

    def Bound(self, theKey: "Standard_GUID", theItem: "opencascade::handle< TPrsStd_Driver > const &") -> "opencascade::handle< TPrsStd_Driver > *":
        return _TPrsStd.TPrsStd_DataMapOfGUIDDriver_Bound(self, theKey, theItem)

    def IsBound(self, theKey: "Standard_GUID") -> "Standard_Boolean":
        return _TPrsStd.TPrsStd_DataMapOfGUIDDriver_IsBound(self, theKey)

    def UnBind(self, theKey: "Standard_GUID") -> "Standard_Boolean":
        return _TPrsStd.TPrsStd_DataMapOfGUIDDriver_UnBind(self, theKey)

    def Seek(self, theKey: "Standard_GUID") -> "opencascade::handle< TPrsStd_Driver > const *":
        return _TPrsStd.TPrsStd_DataMapOfGUIDDriver_Seek(self, theKey)

    def Find(self, *args) -> "Standard_Boolean":
        return _TPrsStd.TPrsStd_DataMapOfGUIDDriver_Find(self, *args)

    def ChangeSeek(self, theKey: "Standard_GUID") -> "opencascade::handle< TPrsStd_Driver > *":
        return _TPrsStd.TPrsStd_DataMapOfGUIDDriver_ChangeSeek(self, theKey)

    def ChangeFind(self, theKey: "Standard_GUID") -> "opencascade::handle< TPrsStd_Driver > &":
        return _TPrsStd.TPrsStd_DataMapOfGUIDDriver_ChangeFind(self, theKey)

    def __call__(self, *args) -> "opencascade::handle< TPrsStd_Driver > &":
        return _TPrsStd.TPrsStd_DataMapOfGUIDDriver___call__(self, *args)

    def Clear(self, *args) -> "void":
        return _TPrsStd.TPrsStd_DataMapOfGUIDDriver_Clear(self, *args)
    __swig_destroy__ = _TPrsStd.delete_TPrsStd_DataMapOfGUIDDriver

    def Size(self) -> "Standard_Integer":
        return _TPrsStd.TPrsStd_DataMapOfGUIDDriver_Size(self)

# Register TPrsStd_DataMapOfGUIDDriver in _TPrsStd:
_TPrsStd.TPrsStd_DataMapOfGUIDDriver_swigregister(TPrsStd_DataMapOfGUIDDriver)

class TPrsStd_AISPresentation(OCC.Core.TDF.TDF_Attribute):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _TPrsStd.TPrsStd_AISPresentation_swiginit(self, _TPrsStd.new_TPrsStd_AISPresentation(*args))

    def AddSelectionMode(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theSelectionMode: int
        theTransaction: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_AISPresentation_AddSelectionMode(self, *args)

    def Color(self, *args) -> "Quantity_NameOfColor":
        r"""
        No available documentation.

        Returns
        -------
        Quantity_NameOfColor

        """
        return _TPrsStd.TPrsStd_AISPresentation_Color(self, *args)

    def Display(self, *args) -> "void":
        r"""
        Display presentation of object in ais viewer. if <update> = true then aisobject is recomputed and all the visualization settings are applied.

        Parameters
        ----------
        update: bool,optional
        	default value is Standard_False

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_AISPresentation_Display(self, *args)

    def Erase(self, *args) -> "void":
        r"""
        Removes the presentation of this ais presentation attribute from the tprsstd_aisviewer. if remove is true, this ais presentation attribute is removed from the interactive context.

        Parameters
        ----------
        remove: bool,optional
        	default value is Standard_False

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_AISPresentation_Erase(self, *args)

    def GetAIS(self, *args) -> "opencascade::handle< AIS_InteractiveObject >":
        r"""
        Returns ais_interactiveobject stored in the presentation attribute.

        Returns
        -------
        opencascade::handle<AIS_InteractiveObject>

        """
        return _TPrsStd.TPrsStd_AISPresentation_GetAIS(self, *args)

    def GetDriverGUID(self, *args) -> "Standard_GUID":
        r"""
        No available documentation.

        Returns
        -------
        Standard_GUID

        """
        return _TPrsStd.TPrsStd_AISPresentation_GetDriverGUID(self, *args)

    @staticmethod
    def GetID(*args) -> "Standard_GUID const &":
        r"""
        Returns the guid for tprsstd_aispresentation attributes.

        Returns
        -------
        Standard_GUID

        """
        return _TPrsStd.TPrsStd_AISPresentation_GetID(*args)

    def GetNbSelectionModes(self, *args) -> "Standard_Integer":
        r"""
        Returns selection mode(s) of the attribute. it starts with 1 .. getnbselectionmodes().

        Returns
        -------
        int

        """
        return _TPrsStd.TPrsStd_AISPresentation_GetNbSelectionModes(self, *args)

    def HasOwnColor(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if this presentation attribute already has a color setting.

        Returns
        -------
        bool

        """
        return _TPrsStd.TPrsStd_AISPresentation_HasOwnColor(self, *args)

    def HasOwnMaterial(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if this presentation attribute already has a material setting.

        Returns
        -------
        bool

        """
        return _TPrsStd.TPrsStd_AISPresentation_HasOwnMaterial(self, *args)

    def HasOwnMode(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TPrsStd.TPrsStd_AISPresentation_HasOwnMode(self, *args)

    def HasOwnSelectionMode(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TPrsStd.TPrsStd_AISPresentation_HasOwnSelectionMode(self, *args)

    def HasOwnTransparency(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if this presentation attribute already has a transparency setting.

        Returns
        -------
        bool

        """
        return _TPrsStd.TPrsStd_AISPresentation_HasOwnTransparency(self, *args)

    def HasOwnWidth(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if this presentation attribute already has a width setting.

        Returns
        -------
        bool

        """
        return _TPrsStd.TPrsStd_AISPresentation_HasOwnWidth(self, *args)

    def IsDisplayed(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if this ais presentation attribute is displayed.

        Returns
        -------
        bool

        """
        return _TPrsStd.TPrsStd_AISPresentation_IsDisplayed(self, *args)

    def Material(self, *args) -> "Graphic3d_NameOfMaterial":
        r"""
        Returns the material setting for this presentation attribute.

        Returns
        -------
        Graphic3d_NameOfMaterial

        """
        return _TPrsStd.TPrsStd_AISPresentation_Material(self, *args)

    def Mode(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _TPrsStd.TPrsStd_AISPresentation_Mode(self, *args)

    def SelectionMode(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        index: int,optional
        	default value is 1

        Returns
        -------
        int

        """
        return _TPrsStd.TPrsStd_AISPresentation_SelectionMode(self, *args)

    @staticmethod
    def Set(*args) -> "opencascade::handle< TPrsStd_AISPresentation >":
        r"""
        Creates or retrieves the presentation attribute on the label l, and sets the guid driver.

        Parameters
        ----------
        L: TDF_Label
        driver: Standard_GUID

        Returns
        -------
        opencascade::handle<TPrsStd_AISPresentation>
        Creates or retrieves the aispresentation attribute attached to master. the guid of the driver will be the guid of master. master is the attribute you want to display.

        Parameters
        ----------
        master: TDF_Attribute

        Returns
        -------
        opencascade::handle<TPrsStd_AISPresentation>

        """
        return _TPrsStd.TPrsStd_AISPresentation_Set(*args)

    def SetColor(self, *args) -> "void":
        r"""
        Sets the color acolor for this presentation attribute.

        Parameters
        ----------
        aColor: Quantity_NameOfColor

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_AISPresentation_SetColor(self, *args)

    def SetDisplayed(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        B: bool

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_AISPresentation_SetDisplayed(self, *args)

    def SetDriverGUID(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        guid: Standard_GUID

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_AISPresentation_SetDriverGUID(self, *args)

    def SetMaterial(self, *args) -> "void":
        r"""
        Sets the material aname for this presentation attribute.

        Parameters
        ----------
        aName: Graphic3d_NameOfMaterial

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_AISPresentation_SetMaterial(self, *args)

    def SetMode(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theMode: int

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_AISPresentation_SetMode(self, *args)

    def SetSelectionMode(self, *args) -> "void":
        r"""
        Sets selection mode. if 'thetransaction' flag is off, modification of the attribute doesn't influence the transaction mechanism (the attribute doesn't participate in undo/redo because of this modification). certainly, if any other data of the attribute is modified (display mode, color, ...), the attribute will be included into undo/redo.

        Parameters
        ----------
        theSelectionMode: int
        theTransaction: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_AISPresentation_SetSelectionMode(self, *args)

    def SetTransparency(self, *args) -> "void":
        r"""
        Sets the transparency value avalue for this presentation attribute. this value is 0.6 by default.

        Parameters
        ----------
        aValue: float,optional
        	default value is 0.6

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_AISPresentation_SetTransparency(self, *args)

    def SetWidth(self, *args) -> "void":
        r"""
        Sets the width awidth for this presentation attribute.

        Parameters
        ----------
        aWidth: float

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_AISPresentation_SetWidth(self, *args)

    def Transparency(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _TPrsStd.TPrsStd_AISPresentation_Transparency(self, *args)

    @staticmethod
    def Unset(*args) -> "void":
        r"""
        Delete (if exist) the presentation attribute associated to the label <l>.

        Parameters
        ----------
        L: TDF_Label

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_AISPresentation_Unset(*args)

    def UnsetColor(self, *args) -> "void":
        r"""
        Removes the color setting from this presentation attribute.

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_AISPresentation_UnsetColor(self, *args)

    def UnsetMaterial(self, *args) -> "void":
        r"""
        Removes the material setting from this presentation attribute.

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_AISPresentation_UnsetMaterial(self, *args)

    def UnsetMode(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_AISPresentation_UnsetMode(self, *args)

    def UnsetSelectionMode(self, *args) -> "void":
        r"""
        Clears all selection modes of the attribute.

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_AISPresentation_UnsetSelectionMode(self, *args)

    def UnsetTransparency(self, *args) -> "void":
        r"""
        Removes the transparency setting from this presentation attribute.

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_AISPresentation_UnsetTransparency(self, *args)

    def UnsetWidth(self, *args) -> "void":
        r"""
        Removes the width setting from this presentation attribute.

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_AISPresentation_UnsetWidth(self, *args)

    def Update(self, *args) -> "void":
        r"""
        Recompute presentation of object and apply the visualization settings.

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_AISPresentation_Update(self, *args)

    def Width(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _TPrsStd.TPrsStd_AISPresentation_Width(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_TPrsStd_AISPresentation_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TPrsStd.delete_TPrsStd_AISPresentation

# Register TPrsStd_AISPresentation in _TPrsStd:
_TPrsStd.TPrsStd_AISPresentation_swigregister(TPrsStd_AISPresentation)

def TPrsStd_AISPresentation_GetID(*args) -> "Standard_GUID const &":
    r"""
    Returns the guid for tprsstd_aispresentation attributes.

    Returns
    -------
    Standard_GUID

    """
    return _TPrsStd.TPrsStd_AISPresentation_GetID(*args)

def TPrsStd_AISPresentation_Set(*args) -> "opencascade::handle< TPrsStd_AISPresentation >":
    r"""
    Creates or retrieves the presentation attribute on the label l, and sets the guid driver.

    Parameters
    ----------
    L: TDF_Label
    driver: Standard_GUID

    Returns
    -------
    opencascade::handle<TPrsStd_AISPresentation>
    Creates or retrieves the aispresentation attribute attached to master. the guid of the driver will be the guid of master. master is the attribute you want to display.

    Parameters
    ----------
    master: TDF_Attribute

    Returns
    -------
    opencascade::handle<TPrsStd_AISPresentation>

    """
    return _TPrsStd.TPrsStd_AISPresentation_Set(*args)

def TPrsStd_AISPresentation_Unset(*args) -> "void":
    r"""
    Delete (if exist) the presentation attribute associated to the label <l>.

    Parameters
    ----------
    L: TDF_Label

    Returns
    -------
    None

    """
    return _TPrsStd.TPrsStd_AISPresentation_Unset(*args)

class TPrsStd_AISViewer(OCC.Core.TDF.TDF_Attribute):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _TPrsStd.TPrsStd_AISViewer_swiginit(self, _TPrsStd.new_TPrsStd_AISViewer(*args))

    @staticmethod
    def Find(*args) -> "Standard_Boolean":
        r"""
        Finds the viewer attribute at the label access, the root of the data framework. calling this function can be used to initialize an ais viewer.

        Parameters
        ----------
        acces: TDF_Label
        A: TPrsStd_AISViewer

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        acces: TDF_Label
        IC: AIS_InteractiveContext

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        acces: TDF_Label
        V: V3d_Viewer

        Returns
        -------
        bool

        """
        return _TPrsStd.TPrsStd_AISViewer_Find(*args)

    @staticmethod
    def GetID(*args) -> "Standard_GUID const &":
        r"""
        Class methods =============.

        Returns
        -------
        Standard_GUID

        """
        return _TPrsStd.TPrsStd_AISViewer_GetID(*args)

    def GetInteractiveContext(self, *args) -> "opencascade::handle< AIS_InteractiveContext >":
        r"""
        Returns the interactive context in this attribute.

        Returns
        -------
        opencascade::handle<AIS_InteractiveContext>

        """
        return _TPrsStd.TPrsStd_AISViewer_GetInteractiveContext(self, *args)

    @staticmethod
    def Has(*args) -> "Standard_Boolean":
        r"""
        Returns true if there is an aisviewer attribute in <acces> data framework.

        Parameters
        ----------
        acces: TDF_Label

        Returns
        -------
        bool

        """
        return _TPrsStd.TPrsStd_AISViewer_Has(*args)

    @staticmethod
    def New(*args) -> "opencascade::handle< TPrsStd_AISViewer >":
        r"""
        Create and set an aisviewer at. raise an exception if has.

        Parameters
        ----------
        access: TDF_Label
        selector: AIS_InteractiveContext

        Returns
        -------
        opencascade::handle<TPrsStd_AISViewer>
        Create and set an aisattribute at root label. the interactive context is build. raise an exception if has.

        Parameters
        ----------
        acces: TDF_Label
        viewer: V3d_Viewer

        Returns
        -------
        opencascade::handle<TPrsStd_AISViewer>

        """
        return _TPrsStd.TPrsStd_AISViewer_New(*args)

    def SetInteractiveContext(self, *args) -> "void":
        r"""
        Sets the interactive context ctx for this attribute.

        Parameters
        ----------
        ctx: AIS_InteractiveContext

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_AISViewer_SetInteractiveContext(self, *args)

    def Update(self, *args) -> "void":
        r"""
        Aisviewer methods =================.

        Parameters
        ----------
        acces: TDF_Label

        Returns
        -------
        None
        Updates the viewer at the label access. access is the root of the data framework.

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_AISViewer_Update(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_TPrsStd_AISViewer_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TPrsStd.delete_TPrsStd_AISViewer

# Register TPrsStd_AISViewer in _TPrsStd:
_TPrsStd.TPrsStd_AISViewer_swigregister(TPrsStd_AISViewer)

def TPrsStd_AISViewer_Find(*args) -> "Standard_Boolean":
    r"""
    Finds the viewer attribute at the label access, the root of the data framework. calling this function can be used to initialize an ais viewer.

    Parameters
    ----------
    acces: TDF_Label
    A: TPrsStd_AISViewer

    Returns
    -------
    bool
    No available documentation.

    Parameters
    ----------
    acces: TDF_Label
    IC: AIS_InteractiveContext

    Returns
    -------
    bool
    No available documentation.

    Parameters
    ----------
    acces: TDF_Label
    V: V3d_Viewer

    Returns
    -------
    bool

    """
    return _TPrsStd.TPrsStd_AISViewer_Find(*args)

def TPrsStd_AISViewer_GetID(*args) -> "Standard_GUID const &":
    r"""
    Class methods =============.

    Returns
    -------
    Standard_GUID

    """
    return _TPrsStd.TPrsStd_AISViewer_GetID(*args)

def TPrsStd_AISViewer_Has(*args) -> "Standard_Boolean":
    r"""
    Returns true if there is an aisviewer attribute in <acces> data framework.

    Parameters
    ----------
    acces: TDF_Label

    Returns
    -------
    bool

    """
    return _TPrsStd.TPrsStd_AISViewer_Has(*args)

def TPrsStd_AISViewer_New(*args) -> "opencascade::handle< TPrsStd_AISViewer >":
    r"""
    Create and set an aisviewer at. raise an exception if has.

    Parameters
    ----------
    access: TDF_Label
    selector: AIS_InteractiveContext

    Returns
    -------
    opencascade::handle<TPrsStd_AISViewer>
    Create and set an aisattribute at root label. the interactive context is build. raise an exception if has.

    Parameters
    ----------
    acces: TDF_Label
    viewer: V3d_Viewer

    Returns
    -------
    opencascade::handle<TPrsStd_AISViewer>

    """
    return _TPrsStd.TPrsStd_AISViewer_New(*args)

class TPrsStd_ConstraintTools(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def ComputeAngle(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aConst: TDataXtd_Constraint
        anAIS: AIS_InteractiveObject

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_ConstraintTools_ComputeAngle(*args)

    @staticmethod
    def ComputeAngleForOneFace(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aConst: TDataXtd_Constraint
        anAIS: AIS_InteractiveObject

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_ConstraintTools_ComputeAngleForOneFace(*args)

    @staticmethod
    def ComputeCoincident(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aConst: TDataXtd_Constraint
        anAIS: AIS_InteractiveObject

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_ConstraintTools_ComputeCoincident(*args)

    @staticmethod
    def ComputeConcentric(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aConst: TDataXtd_Constraint
        anAIS: AIS_InteractiveObject

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_ConstraintTools_ComputeConcentric(*args)

    @staticmethod
    def ComputeDiameter(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aConst: TDataXtd_Constraint
        anAIS: AIS_InteractiveObject

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_ConstraintTools_ComputeDiameter(*args)

    @staticmethod
    def ComputeDistance(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aConst: TDataXtd_Constraint
        anAIS: AIS_InteractiveObject

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_ConstraintTools_ComputeDistance(*args)

    @staticmethod
    def ComputeEqualDistance(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aConst: TDataXtd_Constraint
        anAIS: AIS_InteractiveObject

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_ConstraintTools_ComputeEqualDistance(*args)

    @staticmethod
    def ComputeEqualRadius(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aConst: TDataXtd_Constraint
        anAIS: AIS_InteractiveObject

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_ConstraintTools_ComputeEqualRadius(*args)

    @staticmethod
    def ComputeFix(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aConst: TDataXtd_Constraint
        anAIS: AIS_InteractiveObject

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_ConstraintTools_ComputeFix(*args)

    @staticmethod
    def ComputeMaxRadius(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aConst: TDataXtd_Constraint
        anAIS: AIS_InteractiveObject

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_ConstraintTools_ComputeMaxRadius(*args)

    @staticmethod
    def ComputeMidPoint(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aConst: TDataXtd_Constraint
        anAIS: AIS_InteractiveObject

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_ConstraintTools_ComputeMidPoint(*args)

    @staticmethod
    def ComputeMinRadius(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aConst: TDataXtd_Constraint
        anAIS: AIS_InteractiveObject

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_ConstraintTools_ComputeMinRadius(*args)

    @staticmethod
    def ComputeOffset(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aConst: TDataXtd_Constraint
        anAIS: AIS_InteractiveObject

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_ConstraintTools_ComputeOffset(*args)

    @staticmethod
    def ComputeOthers(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aConst: TDataXtd_Constraint
        anAIS: AIS_InteractiveObject

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_ConstraintTools_ComputeOthers(*args)

    @staticmethod
    def ComputeParallel(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aConst: TDataXtd_Constraint
        anAIS: AIS_InteractiveObject

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_ConstraintTools_ComputeParallel(*args)

    @staticmethod
    def ComputePerpendicular(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aConst: TDataXtd_Constraint
        anAIS: AIS_InteractiveObject

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_ConstraintTools_ComputePerpendicular(*args)

    @staticmethod
    def ComputePlacement(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aConst: TDataXtd_Constraint
        anAIS: AIS_InteractiveObject

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_ConstraintTools_ComputePlacement(*args)

    @staticmethod
    def ComputeRadius(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aConst: TDataXtd_Constraint
        anAIS: AIS_InteractiveObject

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_ConstraintTools_ComputeRadius(*args)

    @staticmethod
    def ComputeRound(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aConst: TDataXtd_Constraint
        anAIS: AIS_InteractiveObject

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_ConstraintTools_ComputeRound(*args)

    @staticmethod
    def ComputeSymmetry(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aConst: TDataXtd_Constraint
        anAIS: AIS_InteractiveObject

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_ConstraintTools_ComputeSymmetry(*args)

    @staticmethod
    def ComputeTangent(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aConst: TDataXtd_Constraint
        anAIS: AIS_InteractiveObject

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_ConstraintTools_ComputeTangent(*args)

    @staticmethod
    def ComputeTextAndValue(*args) -> "Standard_Real &":
        r"""
        No available documentation.

        Parameters
        ----------
        aConst: TDataXtd_Constraint
        aText: TCollection_ExtendedString
        anIsAngle: bool

        Returns
        -------
        aValue: float

        """
        return _TPrsStd.TPrsStd_ConstraintTools_ComputeTextAndValue(*args)

    @staticmethod
    def UpdateOnlyValue(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aConst: TDataXtd_Constraint
        anAIS: AIS_InteractiveObject

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_ConstraintTools_UpdateOnlyValue(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _TPrsStd.TPrsStd_ConstraintTools_swiginit(self, _TPrsStd.new_TPrsStd_ConstraintTools())
    __swig_destroy__ = _TPrsStd.delete_TPrsStd_ConstraintTools

# Register TPrsStd_ConstraintTools in _TPrsStd:
_TPrsStd.TPrsStd_ConstraintTools_swigregister(TPrsStd_ConstraintTools)

def TPrsStd_ConstraintTools_ComputeAngle(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aConst: TDataXtd_Constraint
    anAIS: AIS_InteractiveObject

    Returns
    -------
    None

    """
    return _TPrsStd.TPrsStd_ConstraintTools_ComputeAngle(*args)

def TPrsStd_ConstraintTools_ComputeAngleForOneFace(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aConst: TDataXtd_Constraint
    anAIS: AIS_InteractiveObject

    Returns
    -------
    None

    """
    return _TPrsStd.TPrsStd_ConstraintTools_ComputeAngleForOneFace(*args)

def TPrsStd_ConstraintTools_ComputeCoincident(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aConst: TDataXtd_Constraint
    anAIS: AIS_InteractiveObject

    Returns
    -------
    None

    """
    return _TPrsStd.TPrsStd_ConstraintTools_ComputeCoincident(*args)

def TPrsStd_ConstraintTools_ComputeConcentric(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aConst: TDataXtd_Constraint
    anAIS: AIS_InteractiveObject

    Returns
    -------
    None

    """
    return _TPrsStd.TPrsStd_ConstraintTools_ComputeConcentric(*args)

def TPrsStd_ConstraintTools_ComputeDiameter(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aConst: TDataXtd_Constraint
    anAIS: AIS_InteractiveObject

    Returns
    -------
    None

    """
    return _TPrsStd.TPrsStd_ConstraintTools_ComputeDiameter(*args)

def TPrsStd_ConstraintTools_ComputeDistance(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aConst: TDataXtd_Constraint
    anAIS: AIS_InteractiveObject

    Returns
    -------
    None

    """
    return _TPrsStd.TPrsStd_ConstraintTools_ComputeDistance(*args)

def TPrsStd_ConstraintTools_ComputeEqualDistance(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aConst: TDataXtd_Constraint
    anAIS: AIS_InteractiveObject

    Returns
    -------
    None

    """
    return _TPrsStd.TPrsStd_ConstraintTools_ComputeEqualDistance(*args)

def TPrsStd_ConstraintTools_ComputeEqualRadius(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aConst: TDataXtd_Constraint
    anAIS: AIS_InteractiveObject

    Returns
    -------
    None

    """
    return _TPrsStd.TPrsStd_ConstraintTools_ComputeEqualRadius(*args)

def TPrsStd_ConstraintTools_ComputeFix(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aConst: TDataXtd_Constraint
    anAIS: AIS_InteractiveObject

    Returns
    -------
    None

    """
    return _TPrsStd.TPrsStd_ConstraintTools_ComputeFix(*args)

def TPrsStd_ConstraintTools_ComputeMaxRadius(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aConst: TDataXtd_Constraint
    anAIS: AIS_InteractiveObject

    Returns
    -------
    None

    """
    return _TPrsStd.TPrsStd_ConstraintTools_ComputeMaxRadius(*args)

def TPrsStd_ConstraintTools_ComputeMidPoint(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aConst: TDataXtd_Constraint
    anAIS: AIS_InteractiveObject

    Returns
    -------
    None

    """
    return _TPrsStd.TPrsStd_ConstraintTools_ComputeMidPoint(*args)

def TPrsStd_ConstraintTools_ComputeMinRadius(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aConst: TDataXtd_Constraint
    anAIS: AIS_InteractiveObject

    Returns
    -------
    None

    """
    return _TPrsStd.TPrsStd_ConstraintTools_ComputeMinRadius(*args)

def TPrsStd_ConstraintTools_ComputeOffset(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aConst: TDataXtd_Constraint
    anAIS: AIS_InteractiveObject

    Returns
    -------
    None

    """
    return _TPrsStd.TPrsStd_ConstraintTools_ComputeOffset(*args)

def TPrsStd_ConstraintTools_ComputeOthers(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aConst: TDataXtd_Constraint
    anAIS: AIS_InteractiveObject

    Returns
    -------
    None

    """
    return _TPrsStd.TPrsStd_ConstraintTools_ComputeOthers(*args)

def TPrsStd_ConstraintTools_ComputeParallel(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aConst: TDataXtd_Constraint
    anAIS: AIS_InteractiveObject

    Returns
    -------
    None

    """
    return _TPrsStd.TPrsStd_ConstraintTools_ComputeParallel(*args)

def TPrsStd_ConstraintTools_ComputePerpendicular(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aConst: TDataXtd_Constraint
    anAIS: AIS_InteractiveObject

    Returns
    -------
    None

    """
    return _TPrsStd.TPrsStd_ConstraintTools_ComputePerpendicular(*args)

def TPrsStd_ConstraintTools_ComputePlacement(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aConst: TDataXtd_Constraint
    anAIS: AIS_InteractiveObject

    Returns
    -------
    None

    """
    return _TPrsStd.TPrsStd_ConstraintTools_ComputePlacement(*args)

def TPrsStd_ConstraintTools_ComputeRadius(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aConst: TDataXtd_Constraint
    anAIS: AIS_InteractiveObject

    Returns
    -------
    None

    """
    return _TPrsStd.TPrsStd_ConstraintTools_ComputeRadius(*args)

def TPrsStd_ConstraintTools_ComputeRound(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aConst: TDataXtd_Constraint
    anAIS: AIS_InteractiveObject

    Returns
    -------
    None

    """
    return _TPrsStd.TPrsStd_ConstraintTools_ComputeRound(*args)

def TPrsStd_ConstraintTools_ComputeSymmetry(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aConst: TDataXtd_Constraint
    anAIS: AIS_InteractiveObject

    Returns
    -------
    None

    """
    return _TPrsStd.TPrsStd_ConstraintTools_ComputeSymmetry(*args)

def TPrsStd_ConstraintTools_ComputeTangent(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aConst: TDataXtd_Constraint
    anAIS: AIS_InteractiveObject

    Returns
    -------
    None

    """
    return _TPrsStd.TPrsStd_ConstraintTools_ComputeTangent(*args)

def TPrsStd_ConstraintTools_ComputeTextAndValue(*args) -> "Standard_Real &":
    r"""
    No available documentation.

    Parameters
    ----------
    aConst: TDataXtd_Constraint
    aText: TCollection_ExtendedString
    anIsAngle: bool

    Returns
    -------
    aValue: float

    """
    return _TPrsStd.TPrsStd_ConstraintTools_ComputeTextAndValue(*args)

def TPrsStd_ConstraintTools_UpdateOnlyValue(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aConst: TDataXtd_Constraint
    anAIS: AIS_InteractiveObject

    Returns
    -------
    None

    """
    return _TPrsStd.TPrsStd_ConstraintTools_UpdateOnlyValue(*args)

class TPrsStd_Driver(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def Update(self, *args) -> "Standard_Boolean":
        r"""
        Updates the interactive object ais with information found on the attributes associated with the label l.

        Parameters
        ----------
        L: TDF_Label
        ais: AIS_InteractiveObject

        Returns
        -------
        bool

        """
        return _TPrsStd.TPrsStd_Driver_Update(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_TPrsStd_Driver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TPrsStd.delete_TPrsStd_Driver

# Register TPrsStd_Driver in _TPrsStd:
_TPrsStd.TPrsStd_Driver_swigregister(TPrsStd_Driver)

class TPrsStd_DriverTable(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Default constructor.

        Returns
        -------
        None

        """
        _TPrsStd.TPrsStd_DriverTable_swiginit(self, _TPrsStd.new_TPrsStd_DriverTable(*args))

    def AddDriver(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the driver has been added successfully to the driver table.

        Parameters
        ----------
        guid: Standard_GUID
        driver: TPrsStd_Driver

        Returns
        -------
        bool

        """
        return _TPrsStd.TPrsStd_DriverTable_AddDriver(self, *args)

    def Clear(self, *args) -> "void":
        r"""
        Removes all drivers. returns true if the driver has been removed successfully. if this method is used, the initstandarddrivers method should be called to fill the table with standard drivers.

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_DriverTable_Clear(self, *args)

    def FindDriver(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the driver was found.

        Parameters
        ----------
        guid: Standard_GUID
        driver: TPrsStd_Driver

        Returns
        -------
        bool

        """
        return _TPrsStd.TPrsStd_DriverTable_FindDriver(self, *args)

    @staticmethod
    def Get(*args) -> "opencascade::handle< TPrsStd_DriverTable >":
        r"""
        Returns the static table. if it does not exist, creates it and fills it with standard drivers.

        Returns
        -------
        opencascade::handle<TPrsStd_DriverTable>

        """
        return _TPrsStd.TPrsStd_DriverTable_Get(*args)

    def InitStandardDrivers(self, *args) -> "void":
        r"""
        Fills the table with standard drivers.

        Returns
        -------
        None

        """
        return _TPrsStd.TPrsStd_DriverTable_InitStandardDrivers(self, *args)

    def RemoveDriver(self, *args) -> "Standard_Boolean":
        r"""
        Removes a driver with the given guid. returns true if the driver has been removed successfully.

        Parameters
        ----------
        guid: Standard_GUID

        Returns
        -------
        bool

        """
        return _TPrsStd.TPrsStd_DriverTable_RemoveDriver(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_TPrsStd_DriverTable_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TPrsStd.delete_TPrsStd_DriverTable

# Register TPrsStd_DriverTable in _TPrsStd:
_TPrsStd.TPrsStd_DriverTable_swigregister(TPrsStd_DriverTable)

def TPrsStd_DriverTable_Get(*args) -> "opencascade::handle< TPrsStd_DriverTable >":
    r"""
    Returns the static table. if it does not exist, creates it and fills it with standard drivers.

    Returns
    -------
    opencascade::handle<TPrsStd_DriverTable>

    """
    return _TPrsStd.TPrsStd_DriverTable_Get(*args)

class TPrsStd_AxisDriver(TPrsStd_Driver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs an empty axis driver.

        Returns
        -------
        None

        """
        _TPrsStd.TPrsStd_AxisDriver_swiginit(self, _TPrsStd.new_TPrsStd_AxisDriver(*args))


    @staticmethod
    def DownCast(t):
      return Handle_TPrsStd_AxisDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TPrsStd.delete_TPrsStd_AxisDriver

# Register TPrsStd_AxisDriver in _TPrsStd:
_TPrsStd.TPrsStd_AxisDriver_swigregister(TPrsStd_AxisDriver)

class TPrsStd_ConstraintDriver(TPrsStd_Driver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs an empty constraint driver.

        Returns
        -------
        None

        """
        _TPrsStd.TPrsStd_ConstraintDriver_swiginit(self, _TPrsStd.new_TPrsStd_ConstraintDriver(*args))


    @staticmethod
    def DownCast(t):
      return Handle_TPrsStd_ConstraintDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TPrsStd.delete_TPrsStd_ConstraintDriver

# Register TPrsStd_ConstraintDriver in _TPrsStd:
_TPrsStd.TPrsStd_ConstraintDriver_swigregister(TPrsStd_ConstraintDriver)

class TPrsStd_GeometryDriver(TPrsStd_Driver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs an empty geometry driver.

        Returns
        -------
        None

        """
        _TPrsStd.TPrsStd_GeometryDriver_swiginit(self, _TPrsStd.new_TPrsStd_GeometryDriver(*args))


    @staticmethod
    def DownCast(t):
      return Handle_TPrsStd_GeometryDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TPrsStd.delete_TPrsStd_GeometryDriver

# Register TPrsStd_GeometryDriver in _TPrsStd:
_TPrsStd.TPrsStd_GeometryDriver_swigregister(TPrsStd_GeometryDriver)

class TPrsStd_NamedShapeDriver(TPrsStd_Driver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs an empty named shape driver.

        Returns
        -------
        None

        """
        _TPrsStd.TPrsStd_NamedShapeDriver_swiginit(self, _TPrsStd.new_TPrsStd_NamedShapeDriver(*args))


    @staticmethod
    def DownCast(t):
      return Handle_TPrsStd_NamedShapeDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TPrsStd.delete_TPrsStd_NamedShapeDriver

# Register TPrsStd_NamedShapeDriver in _TPrsStd:
_TPrsStd.TPrsStd_NamedShapeDriver_swigregister(TPrsStd_NamedShapeDriver)

class TPrsStd_PlaneDriver(TPrsStd_Driver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs an empty plane driver.

        Returns
        -------
        None

        """
        _TPrsStd.TPrsStd_PlaneDriver_swiginit(self, _TPrsStd.new_TPrsStd_PlaneDriver(*args))


    @staticmethod
    def DownCast(t):
      return Handle_TPrsStd_PlaneDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TPrsStd.delete_TPrsStd_PlaneDriver

# Register TPrsStd_PlaneDriver in _TPrsStd:
_TPrsStd.TPrsStd_PlaneDriver_swigregister(TPrsStd_PlaneDriver)

class TPrsStd_PointDriver(TPrsStd_Driver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs an empty point driver.

        Returns
        -------
        None

        """
        _TPrsStd.TPrsStd_PointDriver_swiginit(self, _TPrsStd.new_TPrsStd_PointDriver(*args))


    @staticmethod
    def DownCast(t):
      return Handle_TPrsStd_PointDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TPrsStd.delete_TPrsStd_PointDriver

# Register TPrsStd_PointDriver in _TPrsStd:
_TPrsStd.TPrsStd_PointDriver_swigregister(TPrsStd_PointDriver)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Adaptor2d import *
from OCC.Core.IntRes2d import *
from OCC.Core.gp import *
from OCC.Core.TColStd import *
from OCC.Core.GeomAbs import *
from OCC.Core.math import *
from OCC.Core.IntCurve import *
from OCC.Core.Extrema import *
from OCC.Core.Intf import *
from OCC.Core.Bnd import *


class Geom2dInt_ExactIntersectionPointOfTheIntPCurvePCurveOfGInter:
	def __init__(self, C1: Adaptor2d_Curve2d, C2: Adaptor2d_Curve2d, Tol: float) -> None: ...
	def AnErrorOccurred(self) -> bool: ...
	def NbRoots(self) -> int: ...
	@overload
	def Perform(self, Poly1: Geom2dInt_ThePolygon2dOfTheIntPCurvePCurveOfGInter, Poly2: Geom2dInt_ThePolygon2dOfTheIntPCurvePCurveOfGInter) -> Tuple[int, int, float, float]: ...
	@overload
	def Perform(self, Uo: float, Vo: float, UInf: float, VInf: float, USup: float, VSup: float) -> None: ...
	def Roots(self) -> Tuple[float, float]: ...

class Geom2dInt_GInter(IntRes2d_Intersection):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, C: Adaptor2d_Curve2d, TolConf: float, Tol: float) -> None: ...
	@overload
	def __init__(self, C: Adaptor2d_Curve2d, D: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def __init__(self, C1: Adaptor2d_Curve2d, C2: Adaptor2d_Curve2d, TolConf: float, Tol: float) -> None: ...
	@overload
	def __init__(self, C1: Adaptor2d_Curve2d, D1: IntRes2d_Domain, C2: Adaptor2d_Curve2d, TolConf: float, Tol: float) -> None: ...
	@overload
	def __init__(self, C1: Adaptor2d_Curve2d, C2: Adaptor2d_Curve2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def __init__(self, C1: Adaptor2d_Curve2d, D1: IntRes2d_Domain, C2: Adaptor2d_Curve2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	def ComputeDomain(self, C1: Adaptor2d_Curve2d, TolDomain: float) -> IntRes2d_Domain: ...
	def GetMinNbSamples(self) -> int: ...
	@overload
	def Perform(self, C1: Adaptor2d_Curve2d, D1: IntRes2d_Domain, C2: Adaptor2d_Curve2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def Perform(self, C1: Adaptor2d_Curve2d, C2: Adaptor2d_Curve2d, TolConf: float, Tol: float) -> None: ...
	@overload
	def Perform(self, C1: Adaptor2d_Curve2d, D1: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def Perform(self, C1: Adaptor2d_Curve2d, TolConf: float, Tol: float) -> None: ...
	@overload
	def Perform(self, C1: Adaptor2d_Curve2d, D1: IntRes2d_Domain, C2: Adaptor2d_Curve2d, TolConf: float, Tol: float) -> None: ...
	@overload
	def Perform(self, C1: Adaptor2d_Curve2d, C2: Adaptor2d_Curve2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	def SetMinNbSamples(self, theMinNbSamples: int) -> None: ...

class Geom2dInt_Geom2dCurveTool:
	@staticmethod
	def Circle(C: Adaptor2d_Curve2d) -> gp_Circ2d: ...
	@staticmethod
	def D0(C: Adaptor2d_Curve2d, U: float, P: gp_Pnt2d) -> None: ...
	@staticmethod
	def D1(C: Adaptor2d_Curve2d, U: float, P: gp_Pnt2d, T: gp_Vec2d) -> None: ...
	@staticmethod
	def D2(C: Adaptor2d_Curve2d, U: float, P: gp_Pnt2d, T: gp_Vec2d, N: gp_Vec2d) -> None: ...
	@staticmethod
	def D3(C: Adaptor2d_Curve2d, U: float, P: gp_Pnt2d, T: gp_Vec2d, N: gp_Vec2d, V: gp_Vec2d) -> None: ...
	@staticmethod
	def DN(C: Adaptor2d_Curve2d, U: float, N: int) -> gp_Vec2d: ...
	@staticmethod
	def Degree(C: Adaptor2d_Curve2d) -> int: ...
	@staticmethod
	def Ellipse(C: Adaptor2d_Curve2d) -> gp_Elips2d: ...
	@overload
	@staticmethod
	def EpsX(C: Adaptor2d_Curve2d) -> float: ...
	@overload
	@staticmethod
	def EpsX(C: Adaptor2d_Curve2d, Eps_XYZ: float) -> float: ...
	@staticmethod
	def FirstParameter(C: Adaptor2d_Curve2d) -> float: ...
	@staticmethod
	def GetInterval(C: Adaptor2d_Curve2d, Index: int, Tab: TColStd_Array1OfReal) -> Tuple[float, float]: ...
	@staticmethod
	def GetType(C: Adaptor2d_Curve2d) -> GeomAbs_CurveType: ...
	@staticmethod
	def Hyperbola(C: Adaptor2d_Curve2d) -> gp_Hypr2d: ...
	@staticmethod
	def Intervals(C: Adaptor2d_Curve2d, Tab: TColStd_Array1OfReal) -> None: ...
	@staticmethod
	def LastParameter(C: Adaptor2d_Curve2d) -> float: ...
	@staticmethod
	def Line(C: Adaptor2d_Curve2d) -> gp_Lin2d: ...
	@staticmethod
	def NbIntervals(C: Adaptor2d_Curve2d) -> int: ...
	@overload
	@staticmethod
	def NbSamples(C: Adaptor2d_Curve2d) -> int: ...
	@overload
	@staticmethod
	def NbSamples(C: Adaptor2d_Curve2d, U0: float, U1: float) -> int: ...
	@staticmethod
	def Parabola(C: Adaptor2d_Curve2d) -> gp_Parab2d: ...
	@staticmethod
	def Value(C: Adaptor2d_Curve2d, X: float) -> gp_Pnt2d: ...

class Geom2dInt_IntConicCurveOfGInter(IntRes2d_Intersection):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, L: gp_Lin2d, D1: IntRes2d_Domain, PCurve: Adaptor2d_Curve2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def __init__(self, C: gp_Circ2d, D1: IntRes2d_Domain, PCurve: Adaptor2d_Curve2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def __init__(self, E: gp_Elips2d, D1: IntRes2d_Domain, PCurve: Adaptor2d_Curve2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def __init__(self, Prb: gp_Parab2d, D1: IntRes2d_Domain, PCurve: Adaptor2d_Curve2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def __init__(self, H: gp_Hypr2d, D1: IntRes2d_Domain, PCurve: Adaptor2d_Curve2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def Perform(self, L: gp_Lin2d, D1: IntRes2d_Domain, PCurve: Adaptor2d_Curve2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def Perform(self, C: gp_Circ2d, D1: IntRes2d_Domain, PCurve: Adaptor2d_Curve2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def Perform(self, E: gp_Elips2d, D1: IntRes2d_Domain, PCurve: Adaptor2d_Curve2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def Perform(self, Prb: gp_Parab2d, D1: IntRes2d_Domain, PCurve: Adaptor2d_Curve2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def Perform(self, H: gp_Hypr2d, D1: IntRes2d_Domain, PCurve: Adaptor2d_Curve2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...

class Geom2dInt_MyImpParToolOfTheIntersectorOfTheIntConicCurveOfGInter(math_FunctionWithDerivative):
	def __init__(self, IT: IntCurve_IConicTool, PC: Adaptor2d_Curve2d) -> None: ...
	def Derivative(self, Param: float) -> Tuple[bool, float]: ...
	def Value(self, Param: float) -> Tuple[bool, float]: ...
	def Values(self, Param: float) -> Tuple[bool, float, float]: ...

class Geom2dInt_PCLocFOfTheLocateExtPCOfTheProjPCurOfGInter(math_FunctionWithDerivative):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, P: gp_Pnt2d, C: Adaptor2d_Curve2d) -> None: ...
	def Derivative(self, U: float) -> Tuple[bool, float]: ...
	def GetStateNumber(self) -> int: ...
	def Initialize(self, C: Adaptor2d_Curve2d) -> None: ...
	def IsMin(self, N: int) -> bool: ...
	def NbExt(self) -> int: ...
	def Point(self, N: int) -> Extrema_POnCurv2d: ...
	def SearchOfTolerance(self) -> float: ...
	def SetPoint(self, P: gp_Pnt2d) -> None: ...
	def SquareDistance(self, N: int) -> float: ...
	def SubIntervalInitialize(self, theUfirst: float, theUlast: float) -> None: ...
	def Value(self, U: float) -> Tuple[bool, float]: ...
	def Values(self, U: float) -> Tuple[bool, float, float]: ...

class Geom2dInt_TheCurveLocatorOfTheProjPCurOfGInter:
	pass

class Geom2dInt_TheDistBetweenPCurvesOfTheIntPCurvePCurveOfGInter(math_FunctionSetWithDerivatives):
	def __init__(self, curve1: Adaptor2d_Curve2d, curve2: Adaptor2d_Curve2d) -> None: ...
	def Derivatives(self, X: math_Vector, D: math_Matrix) -> bool: ...
	def NbEquations(self) -> int: ...
	def NbVariables(self) -> int: ...
	def Value(self, X: math_Vector, F: math_Vector) -> bool: ...
	def Values(self, X: math_Vector, F: math_Vector, D: math_Matrix) -> bool: ...

class Geom2dInt_TheIntConicCurveOfGInter(IntRes2d_Intersection):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, L: gp_Lin2d, D1: IntRes2d_Domain, PCurve: Adaptor2d_Curve2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def __init__(self, C: gp_Circ2d, D1: IntRes2d_Domain, PCurve: Adaptor2d_Curve2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def __init__(self, E: gp_Elips2d, D1: IntRes2d_Domain, PCurve: Adaptor2d_Curve2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def __init__(self, Prb: gp_Parab2d, D1: IntRes2d_Domain, PCurve: Adaptor2d_Curve2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def __init__(self, H: gp_Hypr2d, D1: IntRes2d_Domain, PCurve: Adaptor2d_Curve2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def Perform(self, L: gp_Lin2d, D1: IntRes2d_Domain, PCurve: Adaptor2d_Curve2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def Perform(self, C: gp_Circ2d, D1: IntRes2d_Domain, PCurve: Adaptor2d_Curve2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def Perform(self, E: gp_Elips2d, D1: IntRes2d_Domain, PCurve: Adaptor2d_Curve2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def Perform(self, Prb: gp_Parab2d, D1: IntRes2d_Domain, PCurve: Adaptor2d_Curve2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def Perform(self, H: gp_Hypr2d, D1: IntRes2d_Domain, PCurve: Adaptor2d_Curve2d, D2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...

class Geom2dInt_TheIntPCurvePCurveOfGInter(IntRes2d_Intersection):
	def __init__(self) -> None: ...
	def GetMinNbSamples(self) -> int: ...
	@overload
	def Perform(self, Curve1: Adaptor2d_Curve2d, Domain1: IntRes2d_Domain, Curve2: Adaptor2d_Curve2d, Domain2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	@overload
	def Perform(self, Curve1: Adaptor2d_Curve2d, Domain1: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	def SetMinNbSamples(self, theMinNbSamples: int) -> None: ...

class Geom2dInt_TheIntersectorOfTheIntConicCurveOfGInter(IntRes2d_Intersection):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, ITool: IntCurve_IConicTool, Dom1: IntRes2d_Domain, PCurve: Adaptor2d_Curve2d, Dom2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...
	def And_Domaine_Objet1_Intersections(self, TheImpTool: IntCurve_IConicTool, TheParCurve: Adaptor2d_Curve2d, TheImpCurveDomain: IntRes2d_Domain, TheParCurveDomain: IntRes2d_Domain, Inter2_And_Domain2: TColStd_Array1OfReal, Inter1: TColStd_Array1OfReal, Resultat1: TColStd_Array1OfReal, Resultat2: TColStd_Array1OfReal, EpsNul: float) -> int: ...
	def FindU(self, parameter: float, point: gp_Pnt2d, TheParCurev: Adaptor2d_Curve2d, TheImpTool: IntCurve_IConicTool) -> float: ...
	def FindV(self, parameter: float, point: gp_Pnt2d, TheImpTool: IntCurve_IConicTool, ParCurve: Adaptor2d_Curve2d, TheParCurveDomain: IntRes2d_Domain, V0: float, V1: float, Tolerance: float) -> float: ...
	def Perform(self, ITool: IntCurve_IConicTool, Dom1: IntRes2d_Domain, PCurve: Adaptor2d_Curve2d, Dom2: IntRes2d_Domain, TolConf: float, Tol: float) -> None: ...

class Geom2dInt_TheLocateExtPCOfTheProjPCurOfGInter:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, P: gp_Pnt2d, C: Adaptor2d_Curve2d, U0: float, TolU: float) -> None: ...
	@overload
	def __init__(self, P: gp_Pnt2d, C: Adaptor2d_Curve2d, U0: float, Umin: float, Usup: float, TolU: float) -> None: ...
	def Initialize(self, C: Adaptor2d_Curve2d, Umin: float, Usup: float, TolU: float) -> None: ...
	def IsDone(self) -> bool: ...
	def IsMin(self) -> bool: ...
	def Perform(self, P: gp_Pnt2d, U0: float) -> None: ...
	def Point(self) -> Extrema_POnCurv2d: ...
	def SquareDistance(self) -> float: ...

class Geom2dInt_ThePolygon2dOfTheIntPCurvePCurveOfGInter(Intf_Polygon2d):
	def __init__(self, Curve: Adaptor2d_Curve2d, NbPnt: int, Domain: IntRes2d_Domain, Tol: float) -> None: ...
	def ApproxParamOnCurve(self, Index: int, ParamOnLine: float) -> float: ...
	def AutoIntersectionIsPossible(self) -> bool: ...
	def CalculRegion(self, x: float, y: float, x1: float, x2: float, y1: float, y2: float) -> int: ...
	@overload
	def Closed(self, clos: bool) -> None: ...
	@overload
	def Closed(self) -> bool: ...
	def ComputeWithBox(self, Curve: Adaptor2d_Curve2d, OtherBox: Bnd_Box2d) -> None: ...
	def DeflectionOverEstimation(self) -> float: ...
	def Dump(self) -> None: ...
	def InfParameter(self) -> float: ...
	def NbSegments(self) -> int: ...
	def Segment(self, theIndex: int, theBegin: gp_Pnt2d, theEnd: gp_Pnt2d) -> None: ...
	def SetDeflectionOverEstimation(self, x: float) -> None: ...
	def SupParameter(self) -> float: ...

class Geom2dInt_TheProjPCurOfGInter:
	@overload
	@staticmethod
	def FindParameter(C: Adaptor2d_Curve2d, Pnt: gp_Pnt2d, Tol: float) -> float: ...
	@overload
	@staticmethod
	def FindParameter(C: Adaptor2d_Curve2d, Pnt: gp_Pnt2d, LowParameter: float, HighParameter: float, Tol: float) -> float: ...

# harray1 classes
# harray2 classes
# hsequence classes

Geom2dInt_Geom2dCurveTool_Circle = Geom2dInt_Geom2dCurveTool.Circle
Geom2dInt_Geom2dCurveTool_D0 = Geom2dInt_Geom2dCurveTool.D0
Geom2dInt_Geom2dCurveTool_D1 = Geom2dInt_Geom2dCurveTool.D1
Geom2dInt_Geom2dCurveTool_D2 = Geom2dInt_Geom2dCurveTool.D2
Geom2dInt_Geom2dCurveTool_D3 = Geom2dInt_Geom2dCurveTool.D3
Geom2dInt_Geom2dCurveTool_DN = Geom2dInt_Geom2dCurveTool.DN
Geom2dInt_Geom2dCurveTool_Degree = Geom2dInt_Geom2dCurveTool.Degree
Geom2dInt_Geom2dCurveTool_Ellipse = Geom2dInt_Geom2dCurveTool.Ellipse
Geom2dInt_Geom2dCurveTool_EpsX = Geom2dInt_Geom2dCurveTool.EpsX
Geom2dInt_Geom2dCurveTool_EpsX = Geom2dInt_Geom2dCurveTool.EpsX
Geom2dInt_Geom2dCurveTool_FirstParameter = Geom2dInt_Geom2dCurveTool.FirstParameter
Geom2dInt_Geom2dCurveTool_GetInterval = Geom2dInt_Geom2dCurveTool.GetInterval
Geom2dInt_Geom2dCurveTool_GetType = Geom2dInt_Geom2dCurveTool.GetType
Geom2dInt_Geom2dCurveTool_Hyperbola = Geom2dInt_Geom2dCurveTool.Hyperbola
Geom2dInt_Geom2dCurveTool_Intervals = Geom2dInt_Geom2dCurveTool.Intervals
Geom2dInt_Geom2dCurveTool_LastParameter = Geom2dInt_Geom2dCurveTool.LastParameter
Geom2dInt_Geom2dCurveTool_Line = Geom2dInt_Geom2dCurveTool.Line
Geom2dInt_Geom2dCurveTool_NbIntervals = Geom2dInt_Geom2dCurveTool.NbIntervals
Geom2dInt_Geom2dCurveTool_NbSamples = Geom2dInt_Geom2dCurveTool.NbSamples
Geom2dInt_Geom2dCurveTool_NbSamples = Geom2dInt_Geom2dCurveTool.NbSamples
Geom2dInt_Geom2dCurveTool_Parabola = Geom2dInt_Geom2dCurveTool.Parabola
Geom2dInt_Geom2dCurveTool_Value = Geom2dInt_Geom2dCurveTool.Value
Geom2dInt_TheProjPCurOfGInter_FindParameter = Geom2dInt_TheProjPCurOfGInter.FindParameter
Geom2dInt_TheProjPCurOfGInter_FindParameter = Geom2dInt_TheProjPCurOfGInter.FindParameter



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
BinObjMgt module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_binobjmgt.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _BinObjMgt
else:
    import _BinObjMgt

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _BinObjMgt.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _BinObjMgt.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BinObjMgt.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BinObjMgt.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _BinObjMgt.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _BinObjMgt.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _BinObjMgt.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _BinObjMgt.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _BinObjMgt.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _BinObjMgt.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BinObjMgt.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _BinObjMgt.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _BinObjMgt.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BinObjMgt.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BinObjMgt.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BinObjMgt.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _BinObjMgt.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _BinObjMgt:
_BinObjMgt.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _BinObjMgt.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.TDF
import OCC.Core.Storage

from enum import IntEnum
from OCC.Core.Exception import *



class BinObjMgt_Persistent(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _BinObjMgt.BinObjMgt_Persistent_swiginit(self, _BinObjMgt.new_BinObjMgt_Persistent(*args))

    def Destroy(self, *args) -> "void":
        r"""
        Frees the allocated memory; this object can be reused after call to init.

        Returns
        -------
        None

        """
        return _BinObjMgt.BinObjMgt_Persistent_Destroy(self, *args)

    def GetAsciiString(self, *args) -> "BinObjMgt_Persistent const &":
        r"""
        No available documentation.

        Parameters
        ----------
        theValue: TCollection_AsciiString

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_GetAsciiString(self, *args)

    def GetBoolean(self, *args) -> "BinObjMgt_Persistent const &":
        r"""
        No available documentation.

        Parameters
        ----------

        Returns
        -------
        theValue: bool

        """
        return _BinObjMgt.BinObjMgt_Persistent_GetBoolean(self, *args)

    def GetByte(self, *args) -> "BinObjMgt_Persistent const &":
        r"""
        No available documentation.

        Parameters
        ----------
        theValue: Standard_Byte

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_GetByte(self, *args)

    def GetByteArray(self, *args) -> "BinObjMgt_Persistent const &":
        r"""
        Get c array of unsigned chars, thelength is the number of elements; thearray must point to a space enough to place thelength elements.

        Parameters
        ----------
        theArray: BinObjMgt_PByte
        theLength: int

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_GetByteArray(self, *args)

    def GetCharArray(self, *args) -> "BinObjMgt_Persistent const &":
        r"""
        Get c array of char, thelength is the number of elements; thearray must point to a space enough to place thelength elements.

        Parameters
        ----------
        theArray: BinObjMgt_PChar
        theLength: int

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_GetCharArray(self, *args)

    def GetCharacter(self, *args) -> "BinObjMgt_Persistent const &":
        r"""
        No available documentation.

        Parameters
        ----------
        theValue: Standard_Character

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_GetCharacter(self, *args)

    def GetExtCharArray(self, *args) -> "BinObjMgt_Persistent const &":
        r"""
        Get c array of extcharacter, thelength is the number of elements; thearray must point to a space enough to place thelength elements.

        Parameters
        ----------
        theArray: BinObjMgt_PExtChar
        theLength: int

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_GetExtCharArray(self, *args)

    def GetExtCharacter(self, *args) -> "BinObjMgt_Persistent const &":
        r"""
        No available documentation.

        Parameters
        ----------
        theValue: Standard_ExtCharacter

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_GetExtCharacter(self, *args)

    def GetExtendedString(self, *args) -> "BinObjMgt_Persistent const &":
        r"""
        No available documentation.

        Parameters
        ----------
        theValue: TCollection_ExtendedString

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_GetExtendedString(self, *args)

    def GetGUID(self, *args) -> "BinObjMgt_Persistent const &":
        r"""
        No available documentation.

        Parameters
        ----------
        theValue: Standard_GUID

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_GetGUID(self, *args)

    def GetIntArray(self, *args) -> "BinObjMgt_Persistent const &":
        r"""
        Get c array of int, thelength is the number of elements; thearray must point to a space enough to place thelength elements.

        Parameters
        ----------
        theArray: BinObjMgt_PInteger
        theLength: int

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_GetIntArray(self, *args)

    def GetInteger(self, *args) -> "BinObjMgt_Persistent const &":
        r"""
        No available documentation.

        Parameters
        ----------

        Returns
        -------
        theValue: int

        """
        return _BinObjMgt.BinObjMgt_Persistent_GetInteger(self, *args)

    def GetLabel(self, *args) -> "BinObjMgt_Persistent const &":
        r"""
        No available documentation.

        Parameters
        ----------
        theDS: TDF_Data
        theValue: TDF_Label

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_GetLabel(self, *args)

    def GetReal(self, *args) -> "BinObjMgt_Persistent const &":
        r"""
        No available documentation.

        Parameters
        ----------

        Returns
        -------
        theValue: float

        """
        return _BinObjMgt.BinObjMgt_Persistent_GetReal(self, *args)

    def GetRealArray(self, *args) -> "BinObjMgt_Persistent const &":
        r"""
        Get c array of double, thelength is the number of elements; thearray must point to a space enough to place thelength elements.

        Parameters
        ----------
        theArray: BinObjMgt_PReal
        theLength: int

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_GetRealArray(self, *args)

    def GetShortReal(self, *args) -> "BinObjMgt_Persistent const &":
        r"""
        No available documentation.

        Parameters
        ----------
        theValue: Standard_ShortReal

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_GetShortReal(self, *args)

    def GetShortRealArray(self, *args) -> "BinObjMgt_Persistent const &":
        r"""
        Get c array of float, thelength is the number of elements; thearray must point to a space enough to place thelength elements.

        Parameters
        ----------
        theArray: BinObjMgt_PShortReal
        theLength: int

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_GetShortRealArray(self, *args)

    def Id(self, *args) -> "Standard_Integer":
        r"""
        Returns the id of the object.

        Returns
        -------
        int

        """
        return _BinObjMgt.BinObjMgt_Persistent_Id(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initializes me to reuse again.

        Returns
        -------
        None

        """
        return _BinObjMgt.BinObjMgt_Persistent_Init(self, *args)

    def IsError(self, *args) -> "Standard_Boolean":
        r"""
        Indicates an error after get methods or setposition.

        Returns
        -------
        bool

        """
        return _BinObjMgt.BinObjMgt_Persistent_IsError(self, *args)

    def IsOK(self, *args) -> "Standard_Boolean":
        r"""
        Indicates a good state after get methods or setposition.

        Returns
        -------
        bool

        """
        return _BinObjMgt.BinObjMgt_Persistent_IsOK(self, *args)

    def Length(self, *args) -> "Standard_Integer":
        r"""
        Returns the length of data.

        Returns
        -------
        int

        """
        return _BinObjMgt.BinObjMgt_Persistent_Length(self, *args)

    def Position(self, *args) -> "Standard_Integer":
        r"""
        Tells the current position for get/put.

        Returns
        -------
        int

        """
        return _BinObjMgt.BinObjMgt_Persistent_Position(self, *args)

    def PutAsciiString(self, *args) -> "BinObjMgt_Persistent &":
        r"""
        Offset in output buffer is word-aligned.

        Parameters
        ----------
        theValue: TCollection_AsciiString

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_PutAsciiString(self, *args)

    def PutBoolean(self, *args) -> "BinObjMgt_Persistent &":
        r"""
        No available documentation.

        Parameters
        ----------
        theValue: bool

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_PutBoolean(self, *args)

    def PutByte(self, *args) -> "BinObjMgt_Persistent &":
        r"""
        No available documentation.

        Parameters
        ----------
        theValue: Standard_Byte

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_PutByte(self, *args)

    def PutByteArray(self, *args) -> "BinObjMgt_Persistent &":
        r"""
        Put c array of unsigned chars, thelength is the number of elements.

        Parameters
        ----------
        theArray: BinObjMgt_PByte
        theLength: int

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_PutByteArray(self, *args)

    def PutCString(self, *args) -> "BinObjMgt_Persistent &":
        r"""
        Offset in output buffer is not aligned.

        Parameters
        ----------
        theValue: char *

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_PutCString(self, *args)

    def PutCharArray(self, *args) -> "BinObjMgt_Persistent &":
        r"""
        Put c array of char, thelength is the number of elements.

        Parameters
        ----------
        theArray: BinObjMgt_PChar
        theLength: int

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_PutCharArray(self, *args)

    def PutCharacter(self, *args) -> "BinObjMgt_Persistent &":
        r"""
        No available documentation.

        Parameters
        ----------
        theValue: Standard_Character

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_PutCharacter(self, *args)

    def PutExtCharArray(self, *args) -> "BinObjMgt_Persistent &":
        r"""
        Put c array of extcharacter, thelength is the number of elements.

        Parameters
        ----------
        theArray: BinObjMgt_PExtChar
        theLength: int

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_PutExtCharArray(self, *args)

    def PutExtCharacter(self, *args) -> "BinObjMgt_Persistent &":
        r"""
        No available documentation.

        Parameters
        ----------
        theValue: Standard_ExtCharacter

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_PutExtCharacter(self, *args)

    def PutExtendedString(self, *args) -> "BinObjMgt_Persistent &":
        r"""
        Offset in output buffer is word-aligned.

        Parameters
        ----------
        theValue: TCollection_ExtendedString

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_PutExtendedString(self, *args)

    def PutGUID(self, *args) -> "BinObjMgt_Persistent &":
        r"""
        No available documentation.

        Parameters
        ----------
        theValue: Standard_GUID

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_PutGUID(self, *args)

    def PutIntArray(self, *args) -> "BinObjMgt_Persistent &":
        r"""
        Put c array of int, thelength is the number of elements.

        Parameters
        ----------
        theArray: BinObjMgt_PInteger
        theLength: int

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_PutIntArray(self, *args)

    def PutInteger(self, *args) -> "BinObjMgt_Persistent &":
        r"""
        No available documentation.

        Parameters
        ----------
        theValue: int

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_PutInteger(self, *args)

    def PutLabel(self, *args) -> "BinObjMgt_Persistent &":
        r"""
        No available documentation.

        Parameters
        ----------
        theValue: TDF_Label

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_PutLabel(self, *args)

    def PutReal(self, *args) -> "BinObjMgt_Persistent &":
        r"""
        No available documentation.

        Parameters
        ----------
        theValue: float

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_PutReal(self, *args)

    def PutRealArray(self, *args) -> "BinObjMgt_Persistent &":
        r"""
        Put c array of double, thelength is the number of elements.

        Parameters
        ----------
        theArray: BinObjMgt_PReal
        theLength: int

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_PutRealArray(self, *args)

    def PutShortReal(self, *args) -> "BinObjMgt_Persistent &":
        r"""
        No available documentation.

        Parameters
        ----------
        theValue: Standard_ShortReal

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_PutShortReal(self, *args)

    def PutShortRealArray(self, *args) -> "BinObjMgt_Persistent &":
        r"""
        Put c array of float, thelength is the number of elements.

        Parameters
        ----------
        theArray: BinObjMgt_PShortReal
        theLength: int

        Returns
        -------
        BinObjMgt_Persistent

        """
        return _BinObjMgt.BinObjMgt_Persistent_PutShortRealArray(self, *args)

    def ReadFromString(self, src: "std::string") -> "void":
        r"""ReadFromString(BinObjMgt_Persistent self, std::string src)"""
        return _BinObjMgt.BinObjMgt_Persistent_ReadFromString(self, src)

    def SetId(self, *args) -> "void":
        r"""
        Sets the id of the object.

        Parameters
        ----------
        theId: int

        Returns
        -------
        None

        """
        return _BinObjMgt.BinObjMgt_Persistent_SetId(self, *args)

    def SetPosition(self, *args) -> "Standard_Boolean":
        r"""
        Sets the current position for get/put. resets an error state depending on the validity of thepos. returns the new state (value of isok()).

        Parameters
        ----------
        thePos: int

        Returns
        -------
        bool

        """
        return _BinObjMgt.BinObjMgt_Persistent_SetPosition(self, *args)

    def SetTypeId(self, *args) -> "void":
        r"""
        Sets the id of the type of the object.

        Parameters
        ----------
        theId: int

        Returns
        -------
        None

        """
        return _BinObjMgt.BinObjMgt_Persistent_SetTypeId(self, *args)

    def Truncate(self, *args) -> "void":
        r"""
        Truncates the buffer by current position, i.e. updates mysize.

        Returns
        -------
        None

        """
        return _BinObjMgt.BinObjMgt_Persistent_Truncate(self, *args)

    def TypeId(self, *args) -> "Standard_Integer":
        r"""
        Returns the id of the type of the object.

        Returns
        -------
        int

        """
        return _BinObjMgt.BinObjMgt_Persistent_TypeId(self, *args)

    def WriteToString(self) -> "std::string":
        r"""WriteToString(BinObjMgt_Persistent self) -> std::string"""
        return _BinObjMgt.BinObjMgt_Persistent_WriteToString(self)

    __repr__ = _dumps_object

    __swig_destroy__ = _BinObjMgt.delete_BinObjMgt_Persistent

# Register BinObjMgt_Persistent in _BinObjMgt:
_BinObjMgt.BinObjMgt_Persistent_swigregister(BinObjMgt_Persistent)

class BinObjMgt_RRelocationTable(OCC.Core.TColStd.TColStd_DataMapOfIntegerTransient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def Clear(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        doReleaseMemory: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        return _BinObjMgt.BinObjMgt_RRelocationTable_Clear(self, *args)

    def GetHeaderData(self, *args) -> "opencascade::handle< Storage_HeaderData > const &":
        r"""
        Returns a handle to the header data of the file that is begin read.

        Returns
        -------
        opencascade::handle<Storage_HeaderData>

        """
        return _BinObjMgt.BinObjMgt_RRelocationTable_GetHeaderData(self, *args)

    def SetHeaderData(self, *args) -> "void":
        r"""
        Sets the storage header data. //! @param theheaderdata header data of the file that is begin read.

        Parameters
        ----------
        theHeaderData: Storage_HeaderData

        Returns
        -------
        None

        """
        return _BinObjMgt.BinObjMgt_RRelocationTable_SetHeaderData(self, *args)

    __repr__ = _dumps_object


    def __init__(self):
        _BinObjMgt.BinObjMgt_RRelocationTable_swiginit(self, _BinObjMgt.new_BinObjMgt_RRelocationTable())
    __swig_destroy__ = _BinObjMgt.delete_BinObjMgt_RRelocationTable

# Register BinObjMgt_RRelocationTable in _BinObjMgt:
_BinObjMgt.BinObjMgt_RRelocationTable_swigregister(BinObjMgt_RRelocationTable)


BinObjMgt_SRelocationTable=OCC.Core.TColStd.TColStd_IndexedMapOfTransient






from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.ShapeProcess import *
from OCC.Core.TopTools import *
from OCC.Core.TopoDS import *
from OCC.Core.TopAbs import *
from OCC.Core.Message import *


class ShapeProcessAPI_ApplySequence:
	def __init__(self, rscName: str, seqName: Optional[str] = "") -> None: ...
	def ClearMap(self) -> None: ...
	def Context(self) -> ShapeProcess_ShapeContext: ...
	def Map(self) -> TopTools_DataMapOfShapeShape: ...
	def PrepareShape(self, shape: TopoDS_Shape, fillmap: Optional[bool] = False, until: Optional[TopAbs_ShapeEnum] = TopAbs_SHAPE, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> TopoDS_Shape: ...
	def PrintPreparationResult(self) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes




from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Message import *
from OCC.Core.Interface import *
from OCC.Core.TColStd import *

#the following typedef cannot be wrapped as is
Transfer_TransferMapOfProcessForFinder = NewType('Transfer_TransferMapOfProcessForFinder', Any)
#the following typedef cannot be wrapped as is
Transfer_TransferMapOfProcessForTransient = NewType('Transfer_TransferMapOfProcessForTransient', Any)

class Transfer_SequenceOfBinder:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class Transfer_SequenceOfFinder:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class Transfer_StatusExec(IntEnum):
	Transfer_StatusInitial: int = ...
	Transfer_StatusRun: int = ...
	Transfer_StatusDone: int = ...
	Transfer_StatusError: int = ...
	Transfer_StatusLoop: int = ...
Transfer_StatusInitial = Transfer_StatusExec.Transfer_StatusInitial
Transfer_StatusRun = Transfer_StatusExec.Transfer_StatusRun
Transfer_StatusDone = Transfer_StatusExec.Transfer_StatusDone
Transfer_StatusError = Transfer_StatusExec.Transfer_StatusError
Transfer_StatusLoop = Transfer_StatusExec.Transfer_StatusLoop

class Transfer_UndefMode(IntEnum):
	Transfer_UndefIgnore: int = ...
	Transfer_UndefFailure: int = ...
	Transfer_UndefContent: int = ...
	Transfer_UndefUser: int = ...
Transfer_UndefIgnore = Transfer_UndefMode.Transfer_UndefIgnore
Transfer_UndefFailure = Transfer_UndefMode.Transfer_UndefFailure
Transfer_UndefContent = Transfer_UndefMode.Transfer_UndefContent
Transfer_UndefUser = Transfer_UndefMode.Transfer_UndefUser

class Transfer_StatusResult(IntEnum):
	Transfer_StatusVoid: int = ...
	Transfer_StatusDefined: int = ...
	Transfer_StatusUsed: int = ...
Transfer_StatusVoid = Transfer_StatusResult.Transfer_StatusVoid
Transfer_StatusDefined = Transfer_StatusResult.Transfer_StatusDefined
Transfer_StatusUsed = Transfer_StatusResult.Transfer_StatusUsed

class Transfer_ActorOfProcessForFinder(Standard_Transient):
	def __init__(self) -> None: ...
	def IsLast(self) -> bool: ...
	def Next(self) -> Transfer_ActorOfProcessForFinder: ...
	def NullResult(self) -> Transfer_Binder: ...
	def Recognize(self, start: Transfer_Finder) -> bool: ...
	def SetLast(self, mode: Optional[bool] = True) -> None: ...
	def SetNext(self, next: Transfer_ActorOfProcessForFinder) -> None: ...
	def Transferring(self, start: Transfer_Finder, TP: Transfer_ProcessForFinder, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> Transfer_Binder: ...
	def TransientResult(self, res: Standard_Transient) -> Transfer_SimpleBinderOfTransient: ...

class Transfer_ActorOfProcessForTransient(Standard_Transient):
	def __init__(self) -> None: ...
	def IsLast(self) -> bool: ...
	def Next(self) -> Transfer_ActorOfProcessForTransient: ...
	def NullResult(self) -> Transfer_Binder: ...
	def Recognize(self, start: Standard_Transient) -> bool: ...
	def SetLast(self, mode: Optional[bool] = True) -> None: ...
	def SetNext(self, next: Transfer_ActorOfProcessForTransient) -> None: ...
	def Transferring(self, start: Standard_Transient, TP: Transfer_ProcessForTransient, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> Transfer_Binder: ...
	def TransientResult(self, res: Standard_Transient) -> Transfer_SimpleBinderOfTransient: ...

class Transfer_Binder(Standard_Transient):
	def AddFail(self, mess: str, orig: Optional[str] = "") -> None: ...
	def AddResult(self, next: Transfer_Binder) -> None: ...
	def AddWarning(self, mess: str, orig: Optional[str] = "") -> None: ...
	def CCheck(self) -> Interface_Check: ...
	def Check(self) -> Interface_Check: ...
	def HasResult(self) -> bool: ...
	def IsMultiple(self) -> bool: ...
	def Merge(self, other: Transfer_Binder) -> None: ...
	def NextResult(self) -> Transfer_Binder: ...
	def ResultType(self) -> Standard_Type: ...
	def ResultTypeName(self) -> str: ...
	def SetAlreadyUsed(self) -> None: ...
	def SetStatusExec(self, stat: Transfer_StatusExec) -> None: ...
	def Status(self) -> Transfer_StatusResult: ...
	def StatusExec(self) -> Transfer_StatusExec: ...

class Transfer_DataInfo:
	@staticmethod
	def Type(ent: Standard_Transient) -> Standard_Type: ...
	@staticmethod
	def TypeName(ent: Standard_Transient) -> str: ...

class Transfer_DispatchControl(Interface_CopyControl):
	def __init__(self, model: Interface_InterfaceModel, TP: Transfer_TransientProcess) -> None: ...
	def Bind(self, ent: Standard_Transient, res: Standard_Transient) -> None: ...
	def Clear(self) -> None: ...
	def Search(self, ent: Standard_Transient, res: Standard_Transient) -> bool: ...
	def StartingModel(self) -> Interface_InterfaceModel: ...
	def TransientProcess(self) -> Transfer_TransientProcess: ...

class Transfer_FindHasher:
	@staticmethod
	def HashCode(theFinder: Transfer_Finder, theUpperBound: int) -> int: ...
	@staticmethod
	def IsEqual(K1: Transfer_Finder, K2: Transfer_Finder) -> bool: ...

class Transfer_Finder(Standard_Transient):
	def AttrList(self) -> False: ...
	def Attribute(self, name: str) -> Standard_Transient: ...
	def AttributeType(self, name: str) -> Interface_ParamType: ...
	def Equates(self, other: Transfer_Finder) -> bool: ...
	def GetAttribute(self, name: str, type: Standard_Type, val: Standard_Transient) -> bool: ...
	def GetAttributes(self, other: Transfer_Finder, fromname: Optional[str] = "", copied: Optional[bool] = True) -> None: ...
	def GetHashCode(self) -> int: ...
	def GetIntegerAttribute(self, name: str) -> Tuple[bool, int]: ...
	def GetRealAttribute(self, name: str) -> Tuple[bool, float]: ...
	def GetStringAttribute(self, name: str, val: str) -> bool: ...
	def IntegerAttribute(self, name: str) -> int: ...
	def RealAttribute(self, name: str) -> float: ...
	def RemoveAttribute(self, name: str) -> bool: ...
	def SameAttributes(self, other: Transfer_Finder) -> None: ...
	def SetAttribute(self, name: str, val: Standard_Transient) -> None: ...
	def SetIntegerAttribute(self, name: str, val: int) -> None: ...
	def SetRealAttribute(self, name: str, val: float) -> None: ...
	def SetStringAttribute(self, name: str, val: str) -> None: ...
	def StringAttribute(self, name: str) -> str: ...
	def ValueType(self) -> Standard_Type: ...
	def ValueTypeName(self) -> str: ...

class Transfer_MapContainer(Standard_Transient):
	def __init__(self) -> None: ...
	def GetMapObjects(self) -> TColStd_DataMapOfTransientTransient: ...
	def SetMapObjects(self, theMapObjects: TColStd_DataMapOfTransientTransient) -> None: ...

class Transfer_ProcessForTransient(Standard_Transient):
	@overload
	def __init__(self, nb: Optional[int] = 10000) -> None: ...
	@overload
	def __init__(self, printer: Message_Messenger, nb: Optional[int] = 10000) -> None: ...
	def AbnormalResult(self) -> Transfer_IteratorOfProcessForTransient: ...
	def Actor(self) -> Transfer_ActorOfProcessForTransient: ...
	def AddError(self, start: Standard_Transient, mess: str, orig: Optional[str] = "") -> None: ...
	@overload
	def AddFail(self, start: Standard_Transient, mess: str, orig: Optional[str] = "") -> None: ...
	@overload
	def AddFail(self, start: Standard_Transient, amsg: Message_Msg) -> None: ...
	def AddMultiple(self, start: Standard_Transient, res: Standard_Transient) -> None: ...
	@overload
	def AddWarning(self, start: Standard_Transient, mess: str, orig: Optional[str] = "") -> None: ...
	@overload
	def AddWarning(self, start: Standard_Transient, amsg: Message_Msg) -> None: ...
	def Bind(self, start: Standard_Transient, binder: Transfer_Binder) -> None: ...
	def BindMultiple(self, start: Standard_Transient) -> None: ...
	def BindTransient(self, start: Standard_Transient, res: Standard_Transient) -> None: ...
	def Check(self, start: Standard_Transient) -> Interface_Check: ...
	def CheckList(self, erronly: bool) -> Interface_CheckIterator: ...
	def CheckListOne(self, start: Standard_Transient, level: int, erronly: bool) -> Interface_CheckIterator: ...
	def CheckNum(self, start: Standard_Transient) -> int: ...
	def Clean(self) -> None: ...
	def Clear(self) -> None: ...
	def CompleteResult(self, withstart: Optional[bool] = False) -> Transfer_IteratorOfProcessForTransient: ...
	def ErrorHandle(self) -> bool: ...
	def Find(self, start: Standard_Transient) -> Transfer_Binder: ...
	def FindElseBind(self, start: Standard_Transient) -> Transfer_Binder: ...
	def FindTransient(self, start: Standard_Transient) -> Standard_Transient: ...
	def FindTypedTransient(self, start: Standard_Transient, atype: Standard_Type, val: Standard_Transient) -> bool: ...
	def GetTypedTransient(self, binder: Transfer_Binder, atype: Standard_Type, val: Standard_Transient) -> bool: ...
	def IsAlreadyUsed(self, start: Standard_Transient) -> bool: ...
	def IsBound(self, start: Standard_Transient) -> bool: ...
	def IsCheckListEmpty(self, start: Standard_Transient, level: int, erronly: bool) -> bool: ...
	def IsLooping(self, alevel: int) -> bool: ...
	def MapIndex(self, start: Standard_Transient) -> int: ...
	def MapItem(self, num: int) -> Transfer_Binder: ...
	def Mapped(self, num: int) -> Standard_Transient: ...
	def Mend(self, start: Standard_Transient, pref: Optional[str] = "") -> None: ...
	def Messenger(self) -> Message_Messenger: ...
	def NbMapped(self) -> int: ...
	def NbRoots(self) -> int: ...
	def NestingLevel(self) -> int: ...
	def Rebind(self, start: Standard_Transient, binder: Transfer_Binder) -> None: ...
	def Recognize(self, start: Standard_Transient) -> bool: ...
	def RemoveResult(self, start: Standard_Transient, level: int, compute: Optional[bool] = True) -> None: ...
	def ResetNestingLevel(self) -> None: ...
	def Resize(self, nb: int) -> None: ...
	def ResultOne(self, start: Standard_Transient, level: int, withstart: Optional[bool] = False) -> Transfer_IteratorOfProcessForTransient: ...
	def Root(self, num: int) -> Standard_Transient: ...
	def RootIndex(self, start: Standard_Transient) -> int: ...
	def RootItem(self, num: int) -> Transfer_Binder: ...
	def RootResult(self, withstart: Optional[bool] = False) -> Transfer_IteratorOfProcessForTransient: ...
	def SendFail(self, start: Standard_Transient, amsg: Message_Msg) -> None: ...
	def SendMsg(self, start: Standard_Transient, amsg: Message_Msg) -> None: ...
	def SendWarning(self, start: Standard_Transient, amsg: Message_Msg) -> None: ...
	def SetActor(self, actor: Transfer_ActorOfProcessForTransient) -> None: ...
	def SetErrorHandle(self, err: bool) -> None: ...
	def SetMessenger(self, messenger: Message_Messenger) -> None: ...
	def SetRoot(self, start: Standard_Transient) -> None: ...
	def SetRootManagement(self, stat: bool) -> None: ...
	def SetTraceLevel(self, tracelev: int) -> None: ...
	def StartTrace(self, binder: Transfer_Binder, start: Standard_Transient, level: int, mode: int) -> None: ...
	def TraceLevel(self) -> int: ...
	def Transfer(self, start: Standard_Transient, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> bool: ...
	def Transferring(self, start: Standard_Transient, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> Transfer_Binder: ...
	def Unbind(self, start: Standard_Transient) -> bool: ...

class Transfer_ResultFromModel(Standard_Transient):
	def __init__(self) -> None: ...
	def CheckList(self, erronly: bool, level: Optional[int] = 2) -> Interface_CheckIterator: ...
	def CheckStatus(self) -> Interface_CheckStatus: ...
	def CheckedList(self, check: Interface_CheckStatus, result: bool) -> TColStd_HSequenceOfTransient: ...
	def ComputeCheckStatus(self, enforce: bool) -> Interface_CheckStatus: ...
	def FileName(self) -> str: ...
	def Fill(self, TP: Transfer_TransientProcess, ent: Standard_Transient) -> bool: ...
	def FillBack(self, TP: Transfer_TransientProcess) -> None: ...
	def HasResult(self) -> bool: ...
	def MainLabel(self) -> str: ...
	def MainNumber(self) -> int: ...
	def MainResult(self) -> Transfer_ResultFromTransient: ...
	def Model(self) -> Interface_InterfaceModel: ...
	def ResultFromKey(self, start: Standard_Transient) -> Transfer_ResultFromTransient: ...
	def Results(self, level: int) -> TColStd_HSequenceOfTransient: ...
	def SetFileName(self, filename: str) -> None: ...
	def SetMainResult(self, amain: Transfer_ResultFromTransient) -> None: ...
	def SetModel(self, model: Interface_InterfaceModel) -> None: ...
	def Strip(self, mode: int) -> None: ...
	def TransferredList(self, level: Optional[int] = 2) -> TColStd_HSequenceOfTransient: ...

class Transfer_ResultFromTransient(Standard_Transient):
	def __init__(self) -> None: ...
	def AddSubResult(self, sub: Transfer_ResultFromTransient) -> None: ...
	def Binder(self) -> Transfer_Binder: ...
	def Check(self) -> Interface_Check: ...
	def CheckStatus(self) -> Interface_CheckStatus: ...
	def ClearSubs(self) -> None: ...
	def Fill(self, TP: Transfer_TransientProcess) -> None: ...
	def FillBack(self, TP: Transfer_TransientProcess) -> None: ...
	def FillMap(self, map: TColStd_IndexedMapOfTransient) -> None: ...
	def HasResult(self) -> bool: ...
	def NbSubResults(self) -> int: ...
	def ResultFromKey(self, key: Standard_Transient) -> Transfer_ResultFromTransient: ...
	def SetBinder(self, binder: Transfer_Binder) -> None: ...
	def SetStart(self, start: Standard_Transient) -> None: ...
	def Start(self) -> Standard_Transient: ...
	def Strip(self) -> None: ...
	def SubResult(self, num: int) -> Transfer_ResultFromTransient: ...

class Transfer_TransferDispatch(Interface_CopyTool):
	@overload
	def __init__(self, amodel: Interface_InterfaceModel, lib: Interface_GeneralLib) -> None: ...
	@overload
	def __init__(self, amodel: Interface_InterfaceModel, protocol: Interface_Protocol) -> None: ...
	@overload
	def __init__(self, amodel: Interface_InterfaceModel) -> None: ...
	def Copy(self, entfrom: Standard_Transient, entto: Standard_Transient, mapped: bool, errstat: bool) -> bool: ...
	def TransientProcess(self) -> Transfer_TransientProcess: ...

class Transfer_TransferInput:
	def __init__(self) -> None: ...
	def Entities(self, list: Transfer_TransferIterator) -> Interface_EntityIterator: ...
	@overload
	def FillModel(self, proc: Transfer_TransientProcess, amodel: Interface_InterfaceModel) -> None: ...
	@overload
	def FillModel(self, proc: Transfer_TransientProcess, amodel: Interface_InterfaceModel, proto: Interface_Protocol, roots: Optional[bool] = True) -> None: ...
	@overload
	def FillModel(self, proc: Transfer_FinderProcess, amodel: Interface_InterfaceModel) -> None: ...
	@overload
	def FillModel(self, proc: Transfer_FinderProcess, amodel: Interface_InterfaceModel, proto: Interface_Protocol, roots: Optional[bool] = True) -> None: ...

class Transfer_TransferIterator:
	def __init__(self) -> None: ...
	def AddItem(self, atr: Transfer_Binder) -> None: ...
	def Check(self) -> Interface_Check: ...
	def HasFails(self) -> bool: ...
	def HasResult(self) -> bool: ...
	def HasTransientResult(self) -> bool: ...
	def HasUniqueResult(self) -> bool: ...
	def HasWarnings(self) -> bool: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def Number(self) -> int: ...
	def ResultType(self) -> Standard_Type: ...
	def SelectBinder(self, atype: Standard_Type, keep: bool) -> None: ...
	def SelectItem(self, num: int, keep: bool) -> None: ...
	def SelectResult(self, atype: Standard_Type, keep: bool) -> None: ...
	def SelectUnique(self, keep: bool) -> None: ...
	def Start(self) -> None: ...
	def Status(self) -> Transfer_StatusExec: ...
	def TransientResult(self) -> Standard_Transient: ...
	def Value(self) -> Transfer_Binder: ...

class Transfer_TransferOutput:
	@overload
	def __init__(self, actor: Transfer_ActorOfTransientProcess, amodel: Interface_InterfaceModel) -> None: ...
	@overload
	def __init__(self, proc: Transfer_TransientProcess, amodel: Interface_InterfaceModel) -> None: ...
	def ListForStatus(self, normal: bool, roots: Optional[bool] = True) -> Interface_EntityIterator: ...
	def Model(self) -> Interface_InterfaceModel: ...
	def ModelForStatus(self, protocol: Interface_Protocol, normal: bool, roots: Optional[bool] = True) -> Interface_InterfaceModel: ...
	def Transfer(self, obj: Standard_Transient, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> None: ...
	@overload
	def TransferRoots(self, protocol: Interface_Protocol, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> None: ...
	@overload
	def TransferRoots(self, G: Interface_Graph, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> None: ...
	@overload
	def TransferRoots(self, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> None: ...
	def TransientProcess(self) -> Transfer_TransientProcess: ...

class Transfer_ActorOfFinderProcess(Transfer_ActorOfProcessForFinder):
	def __init__(self) -> None: ...
	def GetModeTrans(self) -> int: ...
	def SetModeTrans(self, value: int) -> None: ...
	def Transfer(self, start: Transfer_Finder, TP: Transfer_FinderProcess, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> Transfer_Binder: ...
	def TransferTransient(self, start: Standard_Transient, TP: Transfer_FinderProcess, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> Standard_Transient: ...
	def Transferring(self, start: Transfer_Finder, TP: Transfer_ProcessForFinder, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> Transfer_Binder: ...

class Transfer_ActorOfTransientProcess(Transfer_ActorOfProcessForTransient):
	def __init__(self) -> None: ...
	def Transfer(self, start: Standard_Transient, TP: Transfer_TransientProcess, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> Transfer_Binder: ...
	def TransferTransient(self, start: Standard_Transient, TP: Transfer_TransientProcess, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> Standard_Transient: ...
	def Transferring(self, start: Standard_Transient, TP: Transfer_ProcessForTransient, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> Transfer_Binder: ...

class Transfer_FinderProcess(Transfer_ProcessForFinder):
	def __init__(self, nb: Optional[int] = 10000) -> None: ...
	def Model(self) -> Interface_InterfaceModel: ...
	def NextMappedWithAttribute(self, name: str, num0: int) -> int: ...
	def SetModel(self, model: Interface_InterfaceModel) -> None: ...
	def TransientMapper(self, obj: Standard_Transient) -> Transfer_TransientMapper: ...

class Transfer_IteratorOfProcessForFinder(Transfer_TransferIterator):
	def __init__(self, withstarts: bool) -> None: ...
	@overload
	def Add(self, binder: Transfer_Binder) -> None: ...
	@overload
	def Add(self, binder: Transfer_Binder, start: Transfer_Finder) -> None: ...
	def Filter(self, list: Transfer_HSequenceOfFinder, keep: Optional[bool] = True) -> None: ...
	def HasStarting(self) -> bool: ...
	def Starting(self) -> Transfer_Finder: ...

class Transfer_IteratorOfProcessForTransient(Transfer_TransferIterator):
	def __init__(self, withstarts: bool) -> None: ...
	@overload
	def Add(self, binder: Transfer_Binder) -> None: ...
	@overload
	def Add(self, binder: Transfer_Binder, start: Standard_Transient) -> None: ...
	def Filter(self, list: TColStd_HSequenceOfTransient, keep: Optional[bool] = True) -> None: ...
	def HasStarting(self) -> bool: ...
	def Starting(self) -> Standard_Transient: ...

class Transfer_MultipleBinder(Transfer_Binder):
	def __init__(self) -> None: ...
	def AddResult(self, res: Standard_Transient) -> None: ...
	def IsMultiple(self) -> bool: ...
	def MultipleResult(self) -> TColStd_HSequenceOfTransient: ...
	def NbResults(self) -> int: ...
	def ResultType(self) -> Standard_Type: ...
	def ResultTypeName(self) -> str: ...
	def ResultValue(self, num: int) -> Standard_Transient: ...
	def SetMultipleResult(self, mulres: TColStd_HSequenceOfTransient) -> None: ...

class Transfer_SimpleBinderOfTransient(Transfer_Binder):
	def __init__(self) -> None: ...
	@staticmethod
	def GetTypedResult(bnd: Transfer_Binder, atype: Standard_Type, res: Standard_Transient) -> bool: ...
	def Result(self) -> Standard_Transient: ...
	def ResultType(self) -> Standard_Type: ...
	def ResultTypeName(self) -> str: ...
	def SetResult(self, res: Standard_Transient) -> None: ...

class Transfer_TransientListBinder(Transfer_Binder):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, list: TColStd_HSequenceOfTransient) -> None: ...
	def AddResult(self, res: Standard_Transient) -> None: ...
	def IsMultiple(self) -> bool: ...
	def NbTransients(self) -> int: ...
	def Result(self) -> TColStd_HSequenceOfTransient: ...
	def ResultType(self) -> Standard_Type: ...
	def ResultTypeName(self) -> str: ...
	def SetResult(self, num: int, res: Standard_Transient) -> None: ...
	def Transient(self, num: int) -> Standard_Transient: ...

class Transfer_TransientMapper(Transfer_Finder):
	def __init__(self, akey: Standard_Transient) -> None: ...
	def Equates(self, other: Transfer_Finder) -> bool: ...
	def Value(self) -> Standard_Transient: ...
	def ValueType(self) -> Standard_Type: ...
	def ValueTypeName(self) -> str: ...

class Transfer_TransientProcess(Transfer_ProcessForTransient):
	def __init__(self, nb: Optional[int] = 10000) -> None: ...
	def CheckNum(self, ent: Standard_Transient) -> int: ...
	def Context(self) -> False: ...
	def GetContext(self, name: str, type: Standard_Type, ctx: Standard_Transient) -> bool: ...
	def Graph(self) -> Interface_Graph: ...
	def HGraph(self) -> Interface_HGraph: ...
	def HasGraph(self) -> bool: ...
	def IsDataFail(self, ent: Standard_Transient) -> bool: ...
	def IsDataLoaded(self, ent: Standard_Transient) -> bool: ...
	def Model(self) -> Interface_InterfaceModel: ...
	def RootsForTransfer(self) -> TColStd_HSequenceOfTransient: ...
	def SetContext(self, name: str, ctx: Standard_Transient) -> None: ...
	def SetGraph(self, HG: Interface_HGraph) -> None: ...
	def SetModel(self, model: Interface_InterfaceModel) -> None: ...
	def TypedSharings(self, start: Standard_Transient, type: Standard_Type) -> Interface_EntityIterator: ...

class Transfer_VoidBinder(Transfer_Binder):
	def __init__(self) -> None: ...
	def ResultType(self) -> Standard_Type: ...
	def ResultTypeName(self) -> str: ...

class Transfer_ActorDispatch(Transfer_ActorOfTransientProcess):
	@overload
	def __init__(self, amodel: Interface_InterfaceModel, lib: Interface_GeneralLib) -> None: ...
	@overload
	def __init__(self, amodel: Interface_InterfaceModel, protocol: Interface_Protocol) -> None: ...
	@overload
	def __init__(self, amodel: Interface_InterfaceModel) -> None: ...
	def AddActor(self, actor: Transfer_ActorOfTransientProcess) -> None: ...
	def Transfer(self, start: Standard_Transient, TP: Transfer_TransientProcess, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> Transfer_Binder: ...
	def TransferDispatch(self) -> Transfer_TransferDispatch: ...

class Transfer_BinderOfTransientInteger(Transfer_SimpleBinderOfTransient):
	def __init__(self) -> None: ...
	def Integer(self) -> int: ...
	def SetInteger(self, value: int) -> None: ...

#classnotwrapped
class Transfer_ProcessForFinder: ...

# harray1 classes
# harray2 classes
# hsequence classes

class Transfer_HSequenceOfBinder(Transfer_SequenceOfBinder, Standard_Transient):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: Transfer_SequenceOfBinder) -> None: ...
    def Sequence(self) -> Transfer_SequenceOfBinder: ...
    def Append(self, theSequence: Transfer_SequenceOfBinder) -> None: ...


class Transfer_HSequenceOfFinder(Transfer_SequenceOfFinder, Standard_Transient):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: Transfer_SequenceOfFinder) -> None: ...
    def Sequence(self) -> Transfer_SequenceOfFinder: ...
    def Append(self, theSequence: Transfer_SequenceOfFinder) -> None: ...


Transfer_DataInfo_Type = Transfer_DataInfo.Type
Transfer_DataInfo_TypeName = Transfer_DataInfo.TypeName
Transfer_FindHasher_HashCode = Transfer_FindHasher.HashCode
Transfer_FindHasher_IsEqual = Transfer_FindHasher.IsEqual
Transfer_SimpleBinderOfTransient_GetTypedResult = Transfer_SimpleBinderOfTransient.GetTypedResult
